# Generic macros
#---------------
%define name castor
%define castorVersion 2.1.14
%define castorRelease 15

# Partial compilations
#---------------------
%{expand:%define compiling_nostk  %(if [ -z $CASTOR_NOSTK ]; then echo 0; else echo 1; fi)}
%{expand:%define compiling_client %(if [ -z $CASTOR_CLIENT ]; then echo 0; else echo 1; fi)}

# General settings
#-----------------
Summary: Cern Advanced mass STORage
Name: %{name}
Version: %{castorVersion}
Release: %{castorRelease}%{?dist}
Source: %{name}-%{version}-%{castorRelease}.tar.gz
URL: http://cern.ch/castor
License: http://cern.ch/castor/DIST/CONDITIONS
Group: Application/Castor
BuildRoot: %{_builddir}/%{name}-%{version}-root
# only build debug info if you're building the whole code
%if %compiling_client
%define debug_package %{nil}
%endif

%description
The CASTOR Project stands for CERN Advanced STORage Manager, and its goal is to handle LHC data in a fully distributed environment.

%prep
%setup -q

%build
# rpmbuild --define="compilenostk 1" ...
%if 0%{?compilenostk:1} > 0
%define compiling_nostk 1
export CASTOR_NOSTK=%compiling_nostk
%endif

# rpmbuild --define "clientonly 1" ...
%if 0%{?clientonly:1} > 0
%define compiling_client 1
export CASTOR_CLIENT=%compiling_client
# Suppress oracompile.py warnings in clientonly mode
export ORACOMPILE_OPTIONS="--quiet"
%endif

# define castor version (modified by maketar.sh to put the exact version)
MAJOR_CASTOR_VERSION=2.1
MINOR_CASTOR_VERSION=14.15
export MAJOR_CASTOR_VERSION
export MINOR_CASTOR_VERSION
./configure
%if %compiling_client
(cd h; ln -s . shift)
echo "Only compiling client part"
%{__make} -s %{_smp_mflags} client
%else
%{__make} -s %{_smp_mflags}
%endif

%install
# define castor version (modified by maketar.sh to put the exact version)
MAJOR_CASTOR_VERSION=2.1
MINOR_CASTOR_VERSION=14.15
export MAJOR_CASTOR_VERSION
export MINOR_CASTOR_VERSION
%{__rm} -rf ${RPM_BUILD_ROOT}

# rpmbuild --define="compilenostk 1" ...
%if 0%{?compilenostk:1} > 0
export CASTOR_NOSTK=1
%endif

%if %compiling_client
%{__make} installclient DESTDIR=${RPM_BUILD_ROOT} EXPORTMAN=${RPM_BUILD_ROOT}/usr/share/man
%else
%{__make} install DESTDIR=${RPM_BUILD_ROOT} EXPORTMAN=${RPM_BUILD_ROOT}/usr/share/man
%endif

%clean
%{__rm} -rf $RPM_BUILD_ROOT
%{__rm} -rf $RPM_BUILD_DIR/%{name}-%{version}

# The following will be filled dynamically with the rule: make rpm, or make tar
%if ! %compiling_client
%package -n castor-config
Summary: Cern Advanced mass STORage
Group: Application/Castor
%description -n castor-config
castor (Cern Advanced STORage system) - castor.conf example
%files -n castor-config
%defattr(-,root,root)
%attr(0644,root,root) /etc/castor/castor.conf.example
%attr(0644,root,root) /etc/castor/rsyslog.conf.client.example
%attr(0644,root,root) /etc/castor/rsyslog.conf.server.example
%endif

%package -n castor-devel
Summary: Cern Advanced mass STORage
Group: Application/Castor
Requires: castor-lib = %{version}-%{release}
%description -n castor-devel
castor (Cern Advanced STORage system) - API
%files -n castor-devel
%defattr(-,root,root)
%attr(0644,root,bin) %doc /usr/share/man/man3/Cgetopt.3castor.gz
%attr(0644,root,bin) %doc /usr/share/man/man3/Cglobals.3castor.gz
%attr(0644,root,bin) %doc /usr/share/man/man3/Cgrp.3castor.gz
%attr(0644,root,bin) %doc /usr/share/man/man3/Cmutex.3castor.gz
%attr(0644,root,bin) %doc /usr/share/man/man3/Cns_access.3castor.gz
%attr(0644,root,bin) %doc /usr/share/man/man3/Cns_chclass.3castor.gz
%attr(0644,root,bin) %doc /usr/share/man/man3/Cns_chdir.3castor.gz
%attr(0644,root,bin) %doc /usr/share/man/man3/Cns_chmod.3castor.gz
%attr(0644,root,bin) %doc /usr/share/man/man3/Cns_chown.3castor.gz
%attr(0644,root,bin) %doc /usr/share/man/man3/Cns_closedir.3castor.gz
%attr(0644,root,bin) %doc /usr/share/man/man3/Cns_creat.3castor.gz
%attr(0644,root,bin) %doc /usr/share/man/man3/Cns_delcomment.3castor.gz
%attr(0644,root,bin) %doc /usr/share/man/man3/Cns_deleteclass.3castor.gz
%attr(0644,root,bin) %doc /usr/share/man/man3/Cns_delsegbycopyno.3castor.gz
%attr(0644,root,bin) %doc /usr/share/man/man3/Cns_enterclass.3castor.gz
%attr(0644,root,bin) %doc /usr/share/man/man3/Cns_getcomment.3castor.gz
%attr(0644,root,bin) %doc /usr/share/man/man3/Cns_getcwd.3castor.gz
%attr(0644,root,bin) %doc /usr/share/man/man3/Cns_getsegattrs.3castor.gz
%attr(0644,root,bin) %doc /usr/share/man/man3/Cns_lastfseq.3castor.gz
%attr(0644,root,bin) %doc /usr/share/man/man3/Cns_listclass.3castor.gz
%attr(0644,root,bin) %doc /usr/share/man/man3/Cns_listtape.3castor.gz
%attr(0644,root,bin) %doc /usr/share/man/man3/Cns_mkdir.3castor.gz
%attr(0644,root,bin) %doc /usr/share/man/man3/Cns_modifyclass.3castor.gz
%attr(0644,root,bin) %doc /usr/share/man/man3/Cns_opendir.3castor.gz
%attr(0644,root,bin) %doc /usr/share/man/man3/Cns_queryclass.3castor.gz
%attr(0644,root,bin) %doc /usr/share/man/man3/Cns_readdir.3castor.gz
%attr(0644,root,bin) %doc /usr/share/man/man3/Cns_readdirc.3castor.gz
%attr(0644,root,bin) %doc /usr/share/man/man3/Cns_readdirx.3castor.gz
%attr(0644,root,bin) %doc /usr/share/man/man3/Cns_readdirxc.3castor.gz
%attr(0644,root,bin) %doc /usr/share/man/man3/Cns_readdirxt.3castor.gz
%attr(0644,root,bin) %doc /usr/share/man/man3/Cns_rename.3castor.gz
%attr(0644,root,bin) %doc /usr/share/man/man3/Cns_replaceseg.3castor.gz
%attr(0644,root,bin) %doc /usr/share/man/man3/Cns_rewinddir.3castor.gz
%attr(0644,root,bin) %doc /usr/share/man/man3/Cns_rmdir.3castor.gz
%attr(0644,root,bin) %doc /usr/share/man/man3/Cns_selectsrvr.3castor.gz
%attr(0644,root,bin) %doc /usr/share/man/man3/Cns_setatime.3castor.gz
%attr(0644,root,bin) %doc /usr/share/man/man3/Cns_setcomment.3castor.gz
%attr(0644,root,bin) %doc /usr/share/man/man3/Cns_setfsize.3castor.gz
%attr(0644,root,bin) %doc /usr/share/man/man3/Cns_stat.3castor.gz
%attr(0644,root,bin) %doc /usr/share/man/man3/Cns_tapesum.3castor.gz
%attr(0644,root,bin) %doc /usr/share/man/man3/Cns_umask.3castor.gz
%attr(0644,root,bin) %doc /usr/share/man/man3/Cns_unlink.3castor.gz
%attr(0644,root,bin) %doc /usr/share/man/man3/Cns_unlinkbyvid.3castor.gz
%attr(0644,root,bin) %doc /usr/share/man/man3/Cns_updateseg_checksum.3castor.gz
%attr(0644,root,bin) %doc /usr/share/man/man3/Cns_updateseg_status.3castor.gz
%attr(0644,root,bin) %doc /usr/share/man/man3/Cns_updatefile_checksum.3castor.gz
%attr(0644,root,bin) %doc /usr/share/man/man3/Cns_utime.3castor.gz
%attr(0644,root,bin) %doc /usr/share/man/man3/Cns_aborttrans.3castor.gz
%attr(0644,root,bin) %doc /usr/share/man/man3/Cns_endsess.3castor.gz
%attr(0644,root,bin) %doc /usr/share/man/man3/Cns_endtrans.3castor.gz
%attr(0644,root,bin) %doc /usr/share/man/man3/Cns_getacl.3castor.gz
%attr(0644,root,bin) %doc /usr/share/man/man3/Cns_listlinks.3castor.gz
%attr(0644,root,bin) %doc /usr/share/man/man3/Cns_mkdirg.3castor.gz
%attr(0644,root,bin) %doc /usr/share/man/man3/Cns_opendirg.3castor.gz
%attr(0644,root,bin) %doc /usr/share/man/man3/Cns_ping.3castor.gz
%attr(0644,root,bin) %doc /usr/share/man/man3/Cns_readdirg.3castor.gz
%attr(0644,root,bin) %doc /usr/share/man/man3/Cns_readlink.3castor.gz
%attr(0644,root,bin) %doc /usr/share/man/man3/Cns_setacl.3castor.gz
%attr(0644,root,bin) %doc /usr/share/man/man3/Cns_startsess.3castor.gz
%attr(0644,root,bin) %doc /usr/share/man/man3/Cns_starttrans.3castor.gz
%attr(0644,root,bin) %doc /usr/share/man/man3/Cns_statg.3castor.gz
%attr(0644,root,bin) %doc /usr/share/man/man3/Cns_symlink.3castor.gz
%attr(0644,root,bin) %doc /usr/share/man/man3/Csec_api.3castor.gz
%attr(0644,root,bin) %doc /usr/share/man/man3/Cpool.3castor.gz
%attr(0644,root,bin) %doc /usr/share/man/man3/Cpwd.3castor.gz
%attr(0644,root,bin) %doc /usr/share/man/man3/Ctape_dmpfil.3castor.gz
%attr(0644,root,bin) %doc /usr/share/man/man3/Ctape_info.3castor.gz
%attr(0644,root,bin) %doc /usr/share/man/man3/Ctape_kill.3castor.gz
%attr(0644,root,bin) %doc /usr/share/man/man3/Ctape_label.3castor.gz
%attr(0644,root,bin) %doc /usr/share/man/man3/Ctape_mount.3castor.gz
%attr(0644,root,bin) %doc /usr/share/man/man3/Ctape_position.3castor.gz
%attr(0644,root,bin) %doc /usr/share/man/man3/Ctape_reserve.3castor.gz
%attr(0644,root,bin) %doc /usr/share/man/man3/Ctape_rls.3castor.gz
%attr(0644,root,bin) %doc /usr/share/man/man3/Ctape_rstatus.3castor.gz
%attr(0644,root,bin) %doc /usr/share/man/man3/Ctape_status.3castor.gz
%attr(0644,root,bin) %doc /usr/share/man/man3/Cthread.3castor.gz
%attr(0644,root,bin) %doc /usr/share/man/man3/Cupv_add.3castor.gz
%attr(0644,root,bin) %doc /usr/share/man/man3/Cupv_check.3castor.gz
%attr(0644,root,bin) %doc /usr/share/man/man3/Cupv_delete.3castor.gz
%attr(0644,root,bin) %doc /usr/share/man/man3/Cupv_list.3castor.gz
%attr(0644,root,bin) %doc /usr/share/man/man3/Cupv_modify.3castor.gz
%attr(0644,root,bin) %doc /usr/share/man/man3/Cuuid.3castor.gz
%attr(0644,root,bin) %doc /usr/share/man/man3/dlf_init.3castor.gz
%attr(0644,root,bin) %doc /usr/share/man/man3/dlf_write.3castor.gz
%attr(0644,root,bin) %doc /usr/share/man/man3/dlf_regtext.3castor.gz
%attr(0644,root,bin) %doc /usr/share/man/man3/dlf_shutdown.3castor.gz
%attr(0644,root,bin) %doc /usr/share/man/man3/dlf_isinitialized.3castor.gz
%attr(0644,root,bin) %doc /usr/share/man/man3/getacct.3castor.gz
%attr(0644,root,bin) %doc /usr/share/man/man3/getacctent.3castor.gz
%attr(0644,root,bin) %doc /usr/share/man/man3/getcompstat.3castor.gz
%attr(0644,root,bin) %doc /usr/share/man/man3/getconfent.3castor.gz
%attr(0644,root,bin) %doc /usr/share/man/man3/log.3castor.gz
%attr(0644,root,bin) %doc /usr/share/man/man3/netread.3castor.gz
%attr(0644,root,bin) %doc /usr/share/man/man3/netwrite.3castor.gz
%attr(0644,root,bin) %doc /usr/share/man/man3/readlbl.3castor.gz
%attr(0644,root,bin) %doc /usr/share/man/man3/rfio_access.3castor.gz
%attr(0644,root,bin) %doc /usr/share/man/man3/rfio_chmod.3castor.gz
%attr(0644,root,bin) %doc /usr/share/man/man3/rfio_chown.3castor.gz
%attr(0644,root,bin) %doc /usr/share/man/man3/rfio_close.3castor.gz
%attr(0644,root,bin) %doc /usr/share/man/man3/rfio_closedir.3castor.gz
%attr(0644,root,bin) %doc /usr/share/man/man3/rfio_fchmod.3castor.gz
%attr(0644,root,bin) %doc /usr/share/man/man3/rfio_fclose.3castor.gz
%attr(0644,root,bin) %doc /usr/share/man/man3/rfio_feof.3castor.gz
%attr(0644,root,bin) %doc /usr/share/man/man3/rfio_ferror.3castor.gz
%attr(0644,root,bin) %doc /usr/share/man/man3/rfio_fflush.3castor.gz
%attr(0644,root,bin) %doc /usr/share/man/man3/rfio_fileno.3castor.gz
%attr(0644,root,bin) %doc /usr/share/man/man3/rfio_fopen.3castor.gz
%attr(0644,root,bin) %doc /usr/share/man/man3/rfio_fopen64.3castor.gz
%attr(0644,root,bin) %doc /usr/share/man/man3/rfio_fread.3castor.gz
%attr(0644,root,bin) %doc /usr/share/man/man3/rfio_fseek.3castor.gz
%attr(0644,root,bin) %doc /usr/share/man/man3/rfio_fseeko64.3castor.gz
%attr(0644,root,bin) %doc /usr/share/man/man3/rfio_fstat.3castor.gz
%attr(0644,root,bin) %doc /usr/share/man/man3/rfio_fstat64.3castor.gz
%attr(0644,root,bin) %doc /usr/share/man/man3/rfio_ftell.3castor.gz
%attr(0644,root,bin) %doc /usr/share/man/man3/rfio_ftello64.3castor.gz
%attr(0644,root,bin) %doc /usr/share/man/man3/rfio_fwrite.3castor.gz
%attr(0644,root,bin) %doc /usr/share/man/man3/rfio_lockf.3castor.gz
%attr(0644,root,bin) %doc /usr/share/man/man3/rfio_lockf64.3castor.gz
%attr(0644,root,bin) %doc /usr/share/man/man3/rfio_lseek.3castor.gz
%attr(0644,root,bin) %doc /usr/share/man/man3/rfio_lseek64.3castor.gz
%attr(0644,root,bin) %doc /usr/share/man/man3/rfio_lstat.3castor.gz
%attr(0644,root,bin) %doc /usr/share/man/man3/rfio_lstat64.3castor.gz
%attr(0644,root,bin) %doc /usr/share/man/man3/rfio_mkdir.3castor.gz
%attr(0644,root,bin) %doc /usr/share/man/man3/rfio_mstat.3castor.gz
%attr(0644,root,bin) %doc /usr/share/man/man3/rfio_mstat64.3castor.gz
%attr(0644,root,bin) %doc /usr/share/man/man3/rfio_msymlink.3castor.gz
%attr(0644,root,bin) %doc /usr/share/man/man3/rfio_munlink.3castor.gz
%attr(0644,root,bin) %doc /usr/share/man/man3/rfio_open.3castor.gz
%attr(0644,root,bin) %doc /usr/share/man/man3/rfio_open64.3castor.gz
%attr(0644,root,bin) %doc /usr/share/man/man3/rfio_opendir.3castor.gz
%attr(0644,root,bin) %doc /usr/share/man/man3/rfio_pclose.3castor.gz
%attr(0644,root,bin) %doc /usr/share/man/man3/rfio_perror.3castor.gz
%attr(0644,root,bin) %doc /usr/share/man/man3/rfio_popen.3castor.gz
%attr(0644,root,bin) %doc /usr/share/man/man3/rfio_preseek.3castor.gz
%attr(0644,root,bin) %doc /usr/share/man/man3/rfio_preseek64.3castor.gz
%attr(0644,root,bin) %doc /usr/share/man/man3/rfio_read.3castor.gz
%attr(0644,root,bin) %doc /usr/share/man/man3/rfio_readdir.3castor.gz
%attr(0644,root,bin) %doc /usr/share/man/man3/rfio_readlink.3castor.gz
%attr(0644,root,bin) %doc /usr/share/man/man3/rfio_rename.3castor.gz
%attr(0644,root,bin) %doc /usr/share/man/man3/rfio_rewinddir.3castor.gz
%attr(0644,root,bin) %doc /usr/share/man/man3/rfio_rmdir.3castor.gz
%attr(0644,root,bin) %doc /usr/share/man/man3/rfio_serror.3castor.gz
%attr(0644,root,bin) %doc /usr/share/man/man3/rfio_stat.3castor.gz
%attr(0644,root,bin) %doc /usr/share/man/man3/rfio_stat64.3castor.gz
%attr(0644,root,bin) %doc /usr/share/man/man3/rfio_statfs.3castor.gz
%attr(0644,root,bin) %doc /usr/share/man/man3/rfio_symlink.3castor.gz
%attr(0644,root,bin) %doc /usr/share/man/man3/rfio_unlink.3castor.gz
%attr(0644,root,bin) %doc /usr/share/man/man3/rfio_write.3castor.gz
%attr(0644,root,bin) %doc /usr/share/man/man3/rfioreadopt.3castor.gz
%attr(0644,root,bin) %doc /usr/share/man/man3/rfiosetopt.3castor.gz
%attr(0644,root,bin) %doc /usr/share/man/man3/rmc_dismount.3castor.gz
%attr(0644,root,bin) %doc /usr/share/man/man3/rmc_export.3castor.gz
%attr(0644,root,bin) %doc /usr/share/man/man3/rmc_find_cartridge.3castor.gz
%attr(0644,root,bin) %doc /usr/share/man/man3/rmc_get_geometry.3castor.gz
%attr(0644,root,bin) %doc /usr/share/man/man3/rmc_import.3castor.gz
%attr(0644,root,bin) %doc /usr/share/man/man3/rmc_mount.3castor.gz
%attr(0644,root,bin) %doc /usr/share/man/man3/rmc_read_elem_status.3castor.gz
%attr(0644,root,bin) %doc /usr/share/man/man3/rmc_seterrbuf.3castor.gz
%attr(0644,root,bin) %doc /usr/share/man/man3/rwndtape.3castor.gz
%attr(0644,root,bin) %doc /usr/share/man/man3/serrno.3castor.gz
%attr(0644,root,bin) %doc /usr/share/man/man3/skiptape.3castor.gz
%attr(0644,root,bin) %doc /usr/share/man/man3/usrlbl.3castor.gz
%attr(0644,root,bin) %doc /usr/share/man/man3/vdqm_Connect.3castor.gz
%attr(0644,root,bin) %doc /usr/share/man/man3/vdqm_DelDrive.3castor.gz
%attr(0644,root,bin) %doc /usr/share/man/man3/vdqm_DelVolumeReq.3castor.gz
%attr(0644,root,bin) %doc /usr/share/man/man3/vdqm_Disconnect.3castor.gz
%attr(0644,root,bin) %doc /usr/share/man/man3/vdqm_NextDrive.3castor.gz
%attr(0644,root,bin) %doc /usr/share/man/man3/vdqm_NextVol.3castor.gz
%attr(0644,root,bin) %doc /usr/share/man/man3/vdqm_SendVolReq.3castor.gz
%attr(0644,root,bin) %doc /usr/share/man/man3/vdqm_UnitStatus.3castor.gz
%attr(0644,root,bin) %doc /usr/share/man/man3/vmgr_deletedenmap.3castor.gz
%attr(0644,root,bin) %doc /usr/share/man/man3/vmgr_deletedgnmap.3castor.gz
%attr(0644,root,bin) %doc /usr/share/man/man3/vmgr_deletelibrary.3castor.gz
%attr(0644,root,bin) %doc /usr/share/man/man3/vmgr_deletemodel.3castor.gz
%attr(0644,root,bin) %doc /usr/share/man/man3/vmgr_deletepool.3castor.gz
%attr(0644,root,bin) %doc /usr/share/man/man3/vmgr_deletetape.3castor.gz
%attr(0644,root,bin) %doc /usr/share/man/man3/vmgr_deltag.3castor.gz
%attr(0644,root,bin) %doc /usr/share/man/man3/vmgr_enterdenmap.3castor.gz
%attr(0644,root,bin) %doc /usr/share/man/man3/vmgr_enterdenmap_byte_u64.3castor.gz
%attr(0644,root,bin) %doc /usr/share/man/man3/vmgr_enterdgnmap.3castor.gz
%attr(0644,root,bin) %doc /usr/share/man/man3/vmgr_enterlibrary.3castor.gz
%attr(0644,root,bin) %doc /usr/share/man/man3/vmgr_entermodel.3castor.gz
%attr(0644,root,bin) %doc /usr/share/man/man3/vmgr_enterpool.3castor.gz
%attr(0644,root,bin) %doc /usr/share/man/man3/vmgr_entertape.3castor.gz
%attr(0644,root,bin) %doc /usr/share/man/man3/vmgr_gettag.3castor.gz
%attr(0644,root,bin) %doc /usr/share/man/man3/vmgr_gettape.3castor.gz
%attr(0644,root,bin) %doc /usr/share/man/man3/vmgr_listdenmap.3castor.gz
%attr(0644,root,bin) %doc /usr/share/man/man3/vmgr_listdenmap_byte_u64.3castor.gz
%attr(0644,root,bin) %doc /usr/share/man/man3/vmgr_listdgnmap.3castor.gz
%attr(0644,root,bin) %doc /usr/share/man/man3/vmgr_listlibrary.3castor.gz
%attr(0644,root,bin) %doc /usr/share/man/man3/vmgr_listmodel.3castor.gz
%attr(0644,root,bin) %doc /usr/share/man/man3/vmgr_listpool.3castor.gz
%attr(0644,root,bin) %doc /usr/share/man/man3/vmgr_listtape.3castor.gz
%attr(0644,root,bin) %doc /usr/share/man/man3/vmgr_listtape_byte_u64.3castor.gz
%attr(0644,root,bin) %doc /usr/share/man/man3/vmgr_modifylibrary.3castor.gz
%attr(0644,root,bin) %doc /usr/share/man/man3/vmgr_modifymodel.3castor.gz
%attr(0644,root,bin) %doc /usr/share/man/man3/vmgr_modifypool.3castor.gz
%attr(0644,root,bin) %doc /usr/share/man/man3/vmgr_modifytape.3castor.gz
%attr(0644,root,bin) %doc /usr/share/man/man3/vmgr_querylibrary.3castor.gz
%attr(0644,root,bin) %doc /usr/share/man/man3/vmgr_querymodel.3castor.gz
%attr(0644,root,bin) %doc /usr/share/man/man3/vmgr_querypool.3castor.gz
%attr(0644,root,bin) %doc /usr/share/man/man3/vmgr_querytape.3castor.gz
%attr(0644,root,bin) %doc /usr/share/man/man3/vmgr_querytape_byte_u64.3castor.gz
%attr(0644,root,bin) %doc /usr/share/man/man3/vmgr_reclaim.3castor.gz
%attr(0644,root,bin) %doc /usr/share/man/man3/vmgr_seterrbuf.3castor.gz
%attr(0644,root,bin) %doc /usr/share/man/man3/vmgr_settag.3castor.gz
%attr(0644,root,bin) %doc /usr/share/man/man3/vmgr_tpmounted.3castor.gz
%attr(0644,root,bin) %doc /usr/share/man/man3/vmgr_updatetape.3castor.gz
%attr(0644,root,bin) %doc /usr/share/man/man3/wrttpmrk.3castor.gz
%attr(0644,root,bin) %doc /usr/share/man/man4/Castor_limits.4castor.gz
%ifarch x86_64
%attr(0644,root,root) /usr/include/shift.h
%attr(0644,root,root) /usr/include/shift/Castor_limits.h
%attr(0644,root,root) /usr/include/shift/Cgetopt.h
%attr(0644,root,root) /usr/include/shift/Cglobals.h
%attr(0644,root,root) /usr/include/shift/Cgrp.h
%attr(0644,root,root) /usr/include/shift/Cinit.h
%attr(0644,root,root) /usr/include/shift/Cmutex.h
%attr(0644,root,root) /usr/include/shift/Cnetdb.h
%attr(0644,root,root) /usr/include/shift/Cns.h
%attr(0644,root,root) /usr/include/shift/Cns_api.h
%attr(0644,root,root) /usr/include/shift/Cns_constants.h
%attr(0644,root,root) /usr/include/shift/Cns_server.h
%attr(0644,root,root) /usr/include/shift/Cns_struct.h
%attr(0644,root,root) /usr/include/shift/Cpool_api.h
%attr(0644,root,root) /usr/include/shift/Cpwd.h
%attr(0644,root,root) /usr/include/shift/Cregexp.h
%attr(0644,root,root) /usr/include/shift/Cregexp_magic.h
%attr(0644,root,root) /usr/include/shift/Csec.h
%attr(0644,root,root) /usr/include/shift/Csec_api.h
%attr(0644,root,root) /usr/include/shift/Csec_common.h
%attr(0644,root,root) /usr/include/shift/Csec_constants.h
%attr(0644,root,root) /usr/include/shift/Csec_plugin.h
%attr(0644,root,root) /usr/include/shift/Csemaphore.h
%attr(0644,root,root) /usr/include/shift/Csnprintf.h
%attr(0644,root,root) /usr/include/shift/Cstrerror.h
%attr(0644,root,root) /usr/include/shift/Ctape.h
%attr(0644,root,root) /usr/include/shift/Ctape_api.h
%attr(0644,root,root) /usr/include/shift/Ctape_constants.h
%attr(0644,root,root) /usr/include/shift/Cthread_api.h
%attr(0644,root,root) /usr/include/shift/Cthread_flags.h
%attr(0644,root,root) /usr/include/shift/Cthread_typedef.h
%attr(0644,root,root) /usr/include/shift/Cupv.h
%attr(0644,root,root) /usr/include/shift/Cupv_api.h
%attr(0644,root,root) /usr/include/shift/Cupv_constants.h
%attr(0644,root,root) /usr/include/shift/Cupv_server.h
%attr(0644,root,root) /usr/include/shift/Cupv_struct.h
%attr(0644,root,root) /usr/include/shift/Cupv_util.h
%attr(0644,root,root) /usr/include/shift/Cuuid.h
%attr(0644,root,root) /usr/include/shift/RfioTURL.h
%attr(0644,root,root) /usr/include/shift/common.h
%attr(0644,root,root) /usr/include/shift/dlf_api.h
%attr(0644,root,root) /usr/include/shift/getacct.h
%attr(0644,root,root) /usr/include/shift/getacctent.h
%attr(0644,root,root) /usr/include/shift/getconfent.h
%attr(0644,root,root) /usr/include/shift/log.h
%attr(0644,root,root) /usr/include/shift/marshall.h
%attr(0644,root,root) /usr/include/shift/md5.h
%attr(0644,root,root) /usr/include/shift/net.h
%attr(0644,root,root) /usr/include/shift/osdep.h
%attr(0644,root,root) /usr/include/shift/patchlevel.h
%attr(0644,root,root) /usr/include/shift/rfcntl.h
%attr(0644,root,root) /usr/include/shift/rfio.h
%attr(0644,root,root) /usr/include/shift/rfio_api.h
%attr(0644,root,root) /usr/include/shift/rfio_constants.h
%attr(0644,root,root) /usr/include/shift/rfio_errno.h
%attr(0644,root,root) /usr/include/shift/rfio_lcastorfdt.h
%attr(0644,root,root) /usr/include/shift/rtcp.h
%attr(0644,root,root) /usr/include/shift/rtcp_api.h
%attr(0644,root,root) /usr/include/shift/rtcp_constants.h
%attr(0644,root,root) /usr/include/shift/rtcp_server.h
%attr(0644,root,root) /usr/include/shift/scsictl.h
%attr(0644,root,root) /usr/include/shift/serrno.h
%attr(0644,root,root) /usr/include/shift/stage_api.h
%attr(0644,root,root) /usr/include/shift/stage_constants.h
%attr(0644,root,root) /usr/include/shift/stage_limits.h
%attr(0644,root,root) /usr/include/shift/stager_api.h
%attr(0644,root,root) /usr/include/shift/stager_client_api.h
%attr(0644,root,root) /usr/include/shift/stager_constants.h
%attr(0644,root,root) /usr/include/shift/stager_errmsg.h
%attr(0644,root,root) /usr/include/shift/stager_extern_globals.h
%attr(0644,root,root) /usr/include/shift/stager_macros.h
%attr(0644,root,root) /usr/include/shift/stager_mapper.h
%attr(0644,root,root) /usr/include/shift/stager_messages.h
%attr(0644,root,root) /usr/include/shift/stager_mover_api.h
%attr(0644,root,root) /usr/include/shift/stager_util.h
%attr(0644,root,root) /usr/include/shift/stager_uuid.h
%attr(0644,root,root) /usr/include/shift/trace.h
%attr(0644,root,root) /usr/include/shift/u64subr.h
%attr(0644,root,root) /usr/include/shift/util.h
%attr(0644,root,root) /usr/include/shift/vdqm.h
%attr(0644,root,root) /usr/include/shift/vdqm_api.h
%attr(0644,root,root) /usr/include/shift/vdqm_constants.h
%attr(0644,root,root) /usr/include/shift/vmgr.h
%attr(0644,root,root) /usr/include/shift/vmgr_api.h
%attr(0644,root,root) /usr/include/shift/vmgr_constants.h
%attr(0644,root,root) /usr/include/shift/vmgr_server.h
%attr(0644,root,root) /usr/include/shift/vmgr_struct.h
%attr(0644,root,root) /usr/include/shift/ypgetacctent.h
%attr(-,root,root) /usr/lib64/libshift.so
%attr(-,root,root) /usr/lib64/libcastorcommon.so
%attr(-,root,root) /usr/lib64/libcastordlf.so
%attr(-,root,root) /usr/lib64/libcastorns.so
%attr(-,root,root) /usr/lib64/libcastorsecurity.so
%attr(-,root,root) /usr/lib64/libcastorrfio.so
%attr(-,root,root) /usr/lib64/libcastorclient.so
%attr(-,root,root) /usr/lib64/libcastorvmgr.so

%else
%attr(0644,root,root) /usr/include/shift.h
%attr(0644,root,root) /usr/include/shift/Castor_limits.h
%attr(0644,root,root) /usr/include/shift/Cgetopt.h
%attr(0644,root,root) /usr/include/shift/Cglobals.h
%attr(0644,root,root) /usr/include/shift/Cgrp.h
%attr(0644,root,root) /usr/include/shift/Cinit.h
%attr(0644,root,root) /usr/include/shift/Cmutex.h
%attr(0644,root,root) /usr/include/shift/Cnetdb.h
%attr(0644,root,root) /usr/include/shift/Cns.h
%attr(0644,root,root) /usr/include/shift/Cns_api.h
%attr(0644,root,root) /usr/include/shift/Cns_constants.h
%attr(0644,root,root) /usr/include/shift/Cns_server.h
%attr(0644,root,root) /usr/include/shift/Cns_struct.h
%attr(0644,root,root) /usr/include/shift/Cpool_api.h
%attr(0644,root,root) /usr/include/shift/Cpwd.h
%attr(0644,root,root) /usr/include/shift/Cregexp.h
%attr(0644,root,root) /usr/include/shift/Cregexp_magic.h
%attr(0644,root,root) /usr/include/shift/Csec.h
%attr(0644,root,root) /usr/include/shift/Csec_api.h
%attr(0644,root,root) /usr/include/shift/Csec_common.h
%attr(0644,root,root) /usr/include/shift/Csec_constants.h
%attr(0644,root,root) /usr/include/shift/Csec_plugin.h
%attr(0644,root,root) /usr/include/shift/Csemaphore.h
%attr(0644,root,root) /usr/include/shift/Csnprintf.h
%attr(0644,root,root) /usr/include/shift/Cstrerror.h
%attr(0644,root,root) /usr/include/shift/Ctape.h
%attr(0644,root,root) /usr/include/shift/Ctape_api.h
%attr(0644,root,root) /usr/include/shift/Ctape_constants.h
%attr(0644,root,root) /usr/include/shift/Cthread_api.h
%attr(0644,root,root) /usr/include/shift/Cthread_flags.h
%attr(0644,root,root) /usr/include/shift/Cthread_typedef.h
%attr(0644,root,root) /usr/include/shift/Cupv.h
%attr(0644,root,root) /usr/include/shift/Cupv_api.h
%attr(0644,root,root) /usr/include/shift/Cupv_constants.h
%attr(0644,root,root) /usr/include/shift/Cupv_server.h
%attr(0644,root,root) /usr/include/shift/Cupv_struct.h
%attr(0644,root,root) /usr/include/shift/Cupv_util.h
%attr(0644,root,root) /usr/include/shift/Cuuid.h
%attr(0644,root,root) /usr/include/shift/RfioTURL.h
%attr(0644,root,root) /usr/include/shift/common.h
%attr(0644,root,root) /usr/include/shift/dlf_api.h
%attr(0644,root,root) /usr/include/shift/getacct.h
%attr(0644,root,root) /usr/include/shift/getacctent.h
%attr(0644,root,root) /usr/include/shift/getconfent.h
%attr(0644,root,root) /usr/include/shift/log.h
%attr(0644,root,root) /usr/include/shift/marshall.h
%attr(0644,root,root) /usr/include/shift/md5.h
%attr(0644,root,root) /usr/include/shift/net.h
%attr(0644,root,root) /usr/include/shift/osdep.h
%attr(0644,root,root) /usr/include/shift/patchlevel.h
%attr(0644,root,root) /usr/include/shift/rfcntl.h
%attr(0644,root,root) /usr/include/shift/rfio.h
%attr(0644,root,root) /usr/include/shift/rfio_api.h
%attr(0644,root,root) /usr/include/shift/rfio_constants.h
%attr(0644,root,root) /usr/include/shift/rfio_errno.h
%attr(0644,root,root) /usr/include/shift/rfio_lcastorfdt.h
%attr(0644,root,root) /usr/include/shift/rtcp.h
%attr(0644,root,root) /usr/include/shift/rtcp_api.h
%attr(0644,root,root) /usr/include/shift/rtcp_constants.h
%attr(0644,root,root) /usr/include/shift/rtcp_server.h
%attr(0644,root,root) /usr/include/shift/scsictl.h
%attr(0644,root,root) /usr/include/shift/serrno.h
%attr(0644,root,root) /usr/include/shift/stage_api.h
%attr(0644,root,root) /usr/include/shift/stage_constants.h
%attr(0644,root,root) /usr/include/shift/stage_limits.h
%attr(0644,root,root) /usr/include/shift/stager_api.h
%attr(0644,root,root) /usr/include/shift/stager_client_api.h
%attr(0644,root,root) /usr/include/shift/stager_constants.h
%attr(0644,root,root) /usr/include/shift/stager_errmsg.h
%attr(0644,root,root) /usr/include/shift/stager_extern_globals.h
%attr(0644,root,root) /usr/include/shift/stager_macros.h
%attr(0644,root,root) /usr/include/shift/stager_mapper.h
%attr(0644,root,root) /usr/include/shift/stager_messages.h
%attr(0644,root,root) /usr/include/shift/stager_mover_api.h
%attr(0644,root,root) /usr/include/shift/stager_util.h
%attr(0644,root,root) /usr/include/shift/stager_uuid.h
%attr(0644,root,root) /usr/include/shift/trace.h
%attr(0644,root,root) /usr/include/shift/u64subr.h
%attr(0644,root,root) /usr/include/shift/util.h
%attr(0644,root,root) /usr/include/shift/vdqm.h
%attr(0644,root,root) /usr/include/shift/vdqm_api.h
%attr(0644,root,root) /usr/include/shift/vdqm_constants.h
%attr(0644,root,root) /usr/include/shift/vmgr.h
%attr(0644,root,root) /usr/include/shift/vmgr_api.h
%attr(0644,root,root) /usr/include/shift/vmgr_constants.h
%attr(0644,root,root) /usr/include/shift/vmgr_server.h
%attr(0644,root,root) /usr/include/shift/vmgr_struct.h
%attr(0644,root,root) /usr/include/shift/ypgetacctent.h
%attr(-,root,root) /usr/lib/libshift.so
%attr(-,root,root) /usr/lib/libcastorcommon.so
%attr(-,root,root) /usr/lib/libcastordlf.so
%attr(-,root,root) /usr/lib/libcastorns.so
%attr(-,root,root) /usr/lib/libcastorsecurity.so
%attr(-,root,root) /usr/lib/libcastorrfio.so
%attr(-,root,root) /usr/lib/libcastorclient.so
%attr(-,root,root) /usr/lib/libcastorvmgr.so

%endif

%if ! %compiling_client
%package -n castor-gc-server
Summary: Cern Advanced mass STORage
Group: Application/Castor
Requires: logrotate, castor-lib = %{version}-%{release}
%description -n castor-gc-server
castor (Cern Advanced STORage system) - Garbage collector, running on every worker node
%files -n castor-gc-server
%defattr(-,root,root)
%attr(0644,root,bin) %doc /usr/share/man/man8/gcd.8castor.gz
%attr(-,root,bin) %dir /var/log/castor
%attr(0755,stage,st) %dir /var/spool/castor
%attr(0755,root,root) /etc/init.d/gcd
%attr(0644,root,root) /etc/sysconfig/gcd.example
%attr(0644,root,root) %config(noreplace) /etc/logrotate.d/castor-gc-server
%attr(0755,root,root) /usr/bin/gcd
%post -n castor-gc-server
/usr/sbin/groupadd -g 1474 st > /dev/null 2>&1 || :
/usr/sbin/useradd -s /bin/nologin -c "Stager Staging System" -u 14029 -g 1474 stage > /dev/null 2>&1 || :
/sbin/chkconfig --add gcd
/sbin/service gcd condrestart > /dev/null 2>&1 || :
%preun -n castor-gc-server
if [ "$1" = 0 ]; then
    /sbin/service gcd stop > /dev/null 2>&1 || :
    /sbin/chkconfig --del gcd
fi
%endif

%if ! %compiling_client
%package -n castor-hsmtools
Summary: Cern Advanced mass STORage
Group: Application/Castor
Requires: castor-lib = %{version}-%{release}
BuildRequires:  zlib-devel
%description -n castor-hsmtools
castor (Cern Advanced STORage system) - HSM Administration tools e.g. reclaim
%files -n castor-hsmtools
%defattr(-,root,root)
%attr(0644,root,bin) %doc /usr/share/man/man1/reclaim.1castor.gz
%attr(0644,root,bin) %doc /usr/share/man/man1/c2probe.1castor.gz
%attr(0644,root,bin) %doc /usr/share/man/man1/adler32.1castor.gz
%attr(0644,root,bin) %doc /usr/share/man/man1/stager_abort.1castor.gz
%attr(0755,root,root) /usr/bin/reclaim
%attr(0755,root,root) /usr/bin/c2probe
%attr(0755,root,root) /usr/bin/rfcpupd
%attr(0755,root,root) /usr/bin/stager_actualget
%attr(0755,root,root) /usr/bin/stager_actualput
%attr(0755,root,root) /usr/bin/stager_abort
%attr(0755,root,root) /usr/bin/adler32
%endif

%if ! %compiling_client
%package -n castor-dbtools
Summary: Cern Advanced mass STORage
Group: Application/Castor
Requires: cx_Oracle >= 5.1.1, castor-lib-oracle = %{version}-%{release}, castor-lib = %{version}-%{release}
Obsoletes: castor-rmmaster-client
%description -n castor-dbtools
castor (Cern Advanced STORage system) - DB Administration tools - XBS-Obsoletes: castor-rmmaster-client
%files -n castor-dbtools
%defattr(-,root,root)
%attr(0644,root,bin) %doc /usr/share/man/man1/enterfileclass.1castor.gz
%attr(0644,root,bin) %doc /usr/share/man/man1/deletefileclass.1castor.gz
%attr(0644,root,bin) %doc /usr/share/man/man1/printfileclass.1castor.gz
%attr(0644,root,bin) %doc /usr/share/man/man1/entersvcclass.1castor.gz
%attr(0644,root,bin) %doc /usr/share/man/man1/modifysvcclass.1castor.gz
%attr(0644,root,bin) %doc /usr/share/man/man1/deletesvcclass.1castor.gz
%attr(0644,root,bin) %doc /usr/share/man/man1/printsvcclass.1castor.gz
%attr(0644,root,bin) %doc /usr/share/man/man1/enterdiskpool.1castor.gz
%attr(0644,root,bin) %doc /usr/share/man/man1/deletediskpool.1castor.gz
%attr(0644,root,bin) %doc /usr/share/man/man1/printdiskpool.1castor.gz
%attr(0644,root,bin) %doc /usr/share/man/man1/enterrecallgroup.1castor.gz
%attr(0644,root,bin) %doc /usr/share/man/man1/modifyrecallgroup.1castor.gz
%attr(0644,root,bin) %doc /usr/share/man/man1/deleterecallgroup.1castor.gz
%attr(0644,root,bin) %doc /usr/share/man/man1/printrecallgroup.1castor.gz
%attr(0644,root,bin) %doc /usr/share/man/man1/enterrecalluser.1castor.gz
%attr(0644,root,bin) %doc /usr/share/man/man1/modifyrecalluser.1castor.gz
%attr(0644,root,bin) %doc /usr/share/man/man1/deleterecalluser.1castor.gz
%attr(0644,root,bin) %doc /usr/share/man/man1/printrecalluser.1castor.gz
%attr(0644,root,bin) %doc /usr/share/man/man1/entertapepool.1castor.gz
%attr(0644,root,bin) %doc /usr/share/man/man1/modifytapepool.1castor.gz
%attr(0644,root,bin) %doc /usr/share/man/man1/deletetapepool.1castor.gz
%attr(0644,root,bin) %doc /usr/share/man/man1/printtapepool.1castor.gz
%attr(0644,root,bin) %doc /usr/share/man/man1/entermigrationroute.1castor.gz
%attr(0644,root,bin) %doc /usr/share/man/man1/modifymigrationroute.1castor.gz
%attr(0644,root,bin) %doc /usr/share/man/man1/deletemigrationroute.1castor.gz
%attr(0644,root,bin) %doc /usr/share/man/man1/printmigrationroute.1castor.gz
%attr(0644,root,bin) %doc /usr/share/man/man1/deletediskserver.1castor.gz
%attr(0644,root,bin) %doc /usr/share/man/man1/printdiskserver.1castor.gz
%attr(0644,root,bin) %doc /usr/share/man/man1/modifydbconfig.1castor.gz
%attr(0644,root,bin) %doc /usr/share/man/man1/printdbconfig.1castor.gz
%attr(0644,root,bin) %doc /usr/share/man/man1/deletediskcopy.1castor.gz
%attr(0644,root,bin) %doc /usr/share/man/man1/diskserver_qry.1castor.gz
%attr(0644,root,bin) %doc /usr/share/man/man1/draindiskserver.1castor.gz
%attr(0644,root,bin) %doc /usr/share/man/man1/vdqmDBInit.1castor.gz
%attr(0644,root,bin) %doc /usr/share/man/man1/vdqmdeletepriority.1castor.gz
%attr(0644,root,bin) %doc /usr/share/man/man1/vdqmlistpriority.1castor.gz
%attr(0644,root,bin) %doc /usr/share/man/man1/vdqmlistrequest.1castor.gz
%attr(0644,root,bin) %doc /usr/share/man/man1/vdqmsetpriority.1castor.gz
%attr(0644,root,bin) %doc /usr/share/man/man1/adminMultiInstance.1castor.gz
%attr(0644,root,bin) %doc /usr/share/man/man1/migratenewcopy.1castor.gz
%attr(0644,root,bin) %doc /usr/share/man/man1/repack.1castor.gz
%attr(0644,root,bin) %doc /usr/share/man/man1/printmigrationstatus.1castor.gz
%attr(0644,root,bin) %doc /usr/share/man/man1/printrecallstatus.1castor.gz
%attr(0644,root,bin) %doc /usr/share/man/man1/printrecallfilestatus.1castor.gz
%attr(0644,root,bin) %doc /usr/share/man/man1/printrecalltapequeue.1castor.gz
%attr(0644,root,bin) %doc /usr/share/man/man1/printrecalluserqueue.1castor.gz
%attr(0644,root,bin) %doc /usr/share/man/man1/nslistsegs.1castor.gz
%attr(0755,root,root) /usr/bin/enterfileclass
%attr(0755,root,root) /usr/bin/deletefileclass
%attr(0755,root,root) /usr/bin/printfileclass
%attr(0755,root,root) /usr/bin/entersvcclass
%attr(0755,root,root) /usr/bin/modifysvcclass
%attr(0755,root,root) /usr/bin/deletesvcclass
%attr(0755,root,root) /usr/bin/printsvcclass
%attr(0755,root,root) /usr/bin/enterdiskpool
%attr(0755,root,root) /usr/bin/deletediskpool
%attr(0755,root,root) /usr/bin/printdiskpool
%attr(0755,root,root) /usr/bin/enterrecallgroup
%attr(0755,root,root) /usr/bin/modifyrecallgroup
%attr(0755,root,root) /usr/bin/deleterecallgroup
%attr(0755,root,root) /usr/bin/printrecallgroup
%attr(0755,root,root) /usr/bin/enterrecalluser
%attr(0755,root,root) /usr/bin/modifyrecalluser
%attr(0755,root,root) /usr/bin/deleterecalluser
%attr(0755,root,root) /usr/bin/printrecalluser
%attr(0755,root,root) /usr/bin/entertapepool
%attr(0755,root,root) /usr/bin/modifytapepool
%attr(0755,root,root) /usr/bin/deletetapepool
%attr(0755,root,root) /usr/bin/printtapepool
%attr(0755,root,root) /usr/bin/entermigrationroute
%attr(0755,root,root) /usr/bin/modifymigrationroute
%attr(0755,root,root) /usr/bin/deletemigrationroute
%attr(0755,root,root) /usr/bin/printmigrationroute
%attr(0755,root,root) /usr/bin/deletediskserver
%attr(0755,root,root) /usr/bin/printdiskserver
%attr(0755,root,root) /usr/bin/modifydbconfig
%attr(0755,root,root) /usr/bin/printdbconfig
%attr(0755,root,root) /usr/bin/deletediskcopy
%attr(0755,root,root) /usr/bin/checkreplicas
%attr(0755,root,root) /usr/bin/diskserver_qry
%attr(0755,root,root) /usr/bin/draindiskserver
%attr(0755,root,root) /usr/lib/perl/CASTOR/castor_tools.pm
%attr(0644,root,root) /usr/lib/python*/site-packages/castor_tools.py*
%attr(0644,root,root) /usr/lib/python*/site-packages/dlf.py*
%attr(0755,root,root) /usr/bin/vdqmDBInit
%attr(0755,root,root) /usr/bin/vdqmdeletepriority
%attr(0755,root,root) /usr/bin/vdqmlistpriority
%attr(0755,root,root) /usr/bin/vdqmlistrequest
%attr(0755,root,root) /usr/bin/vdqmsetpriority
%attr(0755,root,root) /usr/bin/migratenewcopy
%attr(0755,root,root) /usr/bin/fixFileSize
%attr(0755,root,root) /usr/bin/repack
%attr(0755,root,root) /usr/bin/nslistsegs
%attr(0755,root,root) /usr/bin/printmigrationstatus
%attr(0755,root,root) /usr/bin/printrecallstatus
%attr(0755,root,root) /usr/bin/printrecallfilestatus
%attr(0755,root,root) /usr/bin/printrecalltapequeue
%attr(0755,root,root) /usr/bin/printrecalluserqueue

%endif

%if ! %compiling_client
%package -n castor-job
Summary: Cern Advanced mass STORage
Group: Application/Castor
Requires: logrotate, castor-lib = %{version}-%{release}
BuildRequires:  libattr-devel
%description -n castor-job
castor (Cern Advanced STORage system) - The job giving user access to data on the worker nodes
%files -n castor-job
%defattr(-,root,root)
%attr(-,root,bin) %dir /var/log/castor
%attr(0644,root,root) %config(noreplace) /etc/logrotate.d/castor-job
%attr(6755,stage,st) /usr/bin/stagerjob
%endif

%package -n castor-lib
Summary: Cern Advanced mass STORage
Group: Application/Castor
BuildRequires:  curl-devel, python, krb5-devel, openssl-devel

# For uuid/uuid.h
%if 0%{?rhel} >= 6
BuildRequires: libuuid-devel
%else
BuildRequires: e2fsprogs-devel
%endif
Obsoletes: castor-sysconfig,castor-rtcopy-client,castor-lib-compat,castor-dlf-server,castor-doc,castor-commands,CASTOR-client,castor-stager-clientold,castor-rtcopy-messages,castor-tape-client
%description -n castor-lib
castor (Cern Advanced STORage system) - Static and shared libraries for end-users
%files -n castor-lib
%defattr(-,root,root)
%ifarch x86_64
%attr(-,root,root) /usr/lib64/libshift.so.*
%attr(-,root,root) /usr/lib64/libcastorcommon.so.*
%attr(-,root,root) /usr/lib64/libcastordlf.so.*
%attr(-,root,root) /usr/lib64/libcastorupv.so.*
%attr(-,root,root) /usr/lib64/libcastorns.so.*
%attr(-,root,root) /usr/lib64/libcastorsecurity.so.*
%attr(-,root,root) /usr/lib64/libcastorrfio.so.*
%attr(-,root,root) /usr/lib64/libcastorclient.so.*
%attr(-,root,root) /usr/lib64/libcastorvdqm.so.*
%attr(-,root,root) /usr/lib64/libcastorvmgr.so.*
%attr(-,root,root) /usr/lib64/libcastorsec_plugin_ID.so*
%attr(-,root,root) /usr/lib64/libcastorsec_plugin_KRB5.so*
%else
%attr(-,root,root) /usr/lib/libshift.so.*
%attr(-,root,root) /usr/lib/libcastorcommon.so.*
%attr(-,root,root) /usr/lib/libcastordlf.so.*
%attr(-,root,root) /usr/lib/libcastorupv.so.*
%attr(-,root,root) /usr/lib/libcastorns.so.*
%attr(-,root,root) /usr/lib/libcastorsecurity.so.*
%attr(-,root,root) /usr/lib/libcastorrfio.so.*
%attr(-,root,root) /usr/lib/libcastorclient.so.*
%attr(-,root,root) /usr/lib/libcastorvdqm.so.*
%attr(-,root,root) /usr/lib/libcastorvmgr.so.*
%attr(-,root,root) /usr/lib/libcastorsec_plugin_ID.so*
%attr(-,root,root) /usr/lib/libcastorsec_plugin_KRB5.so*
%endif
%post -n castor-lib
# IP tables modification to allow the castor client to open ports
if [ -e /etc/sysconfig/iptables ]; then
  # Determine the name of the iptables chain to use. #78416
  %if 0%{?rhel} >= 6
  chain="INPUT"
  %else
  chain="RH-Firewall-1-INPUT"
  %endif
  # Update the iptables sysconfig file if necessary.
  if ! /bin/grep -q "controlled by castor-lib RPM" /etc/sysconfig/iptables; then
    /bin/cat <<EOFiptable |\
/bin/sed -i.castor -e "/-A $chain -m state --state ESTABLISHED,RELATED -j ACCEPT/r /dev/stdin" /etc/sysconfig/iptables
# controlled by castor-lib RPM 
# allow callbacks for RFIO, port range corresponds to default callback range
-A $chain -m state --state NEW -m tcp -p tcp --dport 30000:30100 -j ACCEPT
# end of CASTOR-client RPM modifications
EOFiptable
    /sbin/service iptables condrestart > /dev/null 2>&1 || :
  fi
fi
# Call to ldconfig after we installed new libraries
/sbin/ldconfig
# Correct the selinux context of new log files
if [ -x /usr/bin/chcon ]; then
  /usr/bin/chcon -R --reference=/var/log/castor /var/log/castor > /dev/null 2>&1 || :
fi

%postun -n castor-lib
if [ "$1" = 0 ]; then
  # IP tables modification to allow the castor client to open ports
  if [ -e /etc/sysconfig/iptables ]; then
      /bin/sed -i.castor -e '/controlled by castor-lib RPM/,/end of CASTOR-client RPM modifications/d' /etc/sysconfig/iptables
      /sbin/service iptables condrestart > /dev/null 2>&1 || :
  fi
  # call to ldconfig after we uninstalled libraries
  /sbin/ldconfig
fi

%if ! %compiling_client
%package -n castor-transfer-manager
Summary: Cern Advanced mass STORage
Group: Application/Castor
Requires: python, logrotate, cx_Oracle >= 5.1.1, python-daemon, python-rpyc >= 3.1, castor-lib = %{version}-%{release}, castor-dbtools = %{version}-%{release}
Obsoletes: castor-rmmaster-server
%description -n castor-transfer-manager
castor (Cern Advanced STORage system) - Transfer manager daemon for Castor, central server package - XBS-Obsoletes: castor-rmmaster-server
%files -n castor-transfer-manager
%defattr(-,root,root)
%attr(0644,root,bin) %doc /usr/share/man/man8/transfermanagerd.8castor.gz
%attr(-,root,bin) %dir /var/log/castor
%attr(0755,root,root) /etc/init.d/transfermanagerd
%attr(0644,root,root) /etc/sysconfig/transfermanagerd.example
%attr(0755,root,root) /usr/bin/transfermanagerd
%attr(0644,root,root) %config(noreplace) /etc/logrotate.d/castor-transfer-manager
%attr(0644,root,root) /usr/lib/python*/site-packages/serverqueue.py*
%attr(0644,root,root) /usr/lib/python*/site-packages/dispatcher.py*
%attr(0644,root,root) /usr/lib/python*/site-packages/aborter.py*
%attr(0644,root,root) /usr/lib/python*/site-packages/synchronizer.py*
%attr(0644,root,root) /usr/lib/python*/site-packages/suicider.py*
%attr(0644,root,root) /usr/lib/python*/site-packages/reportmanager.py*
%attr(0644,root,root) /usr/lib/python*/site-packages/diskserverlistcache.py*
%attr(0644,root,root) /usr/lib/python*/site-packages/modifydiskservers.py*
%attr(0644,root,root) /usr/lib/python*/site-packages/connectionpool.py*
%attr(0644,root,root) /usr/lib/python*/site-packages/transfermanagerdlf.py*
%attr(0644,root,root) /usr/lib/python*/site-packages/threadpoolserver.py*
%attr(0644,root,root) /usr/lib/python*/site-packages/transfer.py*
%post -n castor-transfer-manager
/sbin/chkconfig --add transfermanagerd
/sbin/service transfermanagerd condrestart > /dev/null 2>&1 || :
%preun -n castor-transfer-manager
if [ "$1" = 0 ]; then
    /sbin/service transfermanagerd stop > /dev/null 2>&1 || :
    /sbin/chkconfig --del transfermanagerd
fi
%endif

%if ! %compiling_client
%package -n castor-transfer-manager-client
Summary: Cern Advanced mass STORage
Group: Application/Castor
Requires: python, logrotate, python-rpyc >= 3.1, castor-lib = %{version}-%{release}
%description -n castor-transfer-manager-client
castor (Cern Advanced STORage system) - Transfer manager daemon for Castor, client package
%files -n castor-transfer-manager-client
%defattr(-,root,root)
%attr(0644,root,bin) %doc /usr/share/man/man1/listtransfers.1castor.gz
%attr(0644,root,bin) %doc /usr/share/man/man1/killtransfers.1castor.gz
%attr(0644,root,bin) %doc /usr/share/man/man1/draintransfers.1castor.gz
%attr(0644,root,bin) %doc /usr/share/man/man1/modifydiskserver.1castor.gz
%attr(0755,root,root) /usr/bin/listtransfers
%attr(0755,root,root) /usr/bin/draintransfers
%attr(0755,root,root) /usr/bin/killtransfers
%attr(0755,root,root) /usr/bin/modifydiskserver
%endif

%if ! %compiling_client
%package -n castor-diskserver-manager
Summary: Cern Advanced mass STORage
Group: Application/Castor
Requires: python, logrotate, python-daemon, python-rpyc >= 3.1, castor-job = %{version}-%{release}, castor-lib = %{version}-%{release}
Conflicts: castor-dbtools,castor-transfer-manager
Obsoletes: castor-rmnode-server
%description -n castor-diskserver-manager
castor (Cern Advanced STORage system) - Disk server manager of CASTOR - XBS-Obsoletes: castor-rmnode-server
%files -n castor-diskserver-manager
%defattr(-,root,root)
%attr(0644,root,bin) %doc /usr/share/man/man8/diskmanagerd.8castor.gz
%attr(-,root,bin) %dir /var/log/castor
%attr(0755,root,root) /etc/init.d/diskmanagerd
%attr(0644,root,root) /etc/sysconfig/diskmanagerd.example
%attr(0755,root,root) /usr/bin/diskmanagerd
%attr(0644,root,root) %config(noreplace) /etc/logrotate.d/castor-diskserver-manager
%attr(0644,root,root) /usr/lib/python*/site-packages/localqueue.py*
%attr(0644,root,root) /usr/lib/python*/site-packages/runningtransfersset.py*
%attr(0644,root,root) /usr/lib/python*/site-packages/activitycontrol.py*
%attr(0644,root,root) /usr/lib/python*/site-packages/activitycontrolchecker.py*
%attr(0644,root,root) /usr/lib/python*/site-packages/manager.py*
%attr(0644,root,root) /usr/lib/python*/site-packages/reporter.py*
%attr(0644,root,root) /usr/lib/python*/site-packages/castor_tools.py*
%attr(0644,root,root) /usr/lib/python*/site-packages/connectionpool.py*
%attr(0644,root,root) /usr/lib/python*/site-packages/dlf.py*
%attr(0644,root,root) /usr/lib/python*/site-packages/diskmanagerdlf.py*
%attr(0644,root,root) /usr/lib/python*/site-packages/threadpoolserver.py*
%attr(0644,root,root) /usr/lib/python*/site-packages/transfer.py*
%post -n castor-diskserver-manager
/sbin/chkconfig --add diskmanagerd
/sbin/service diskmanagerd condrestart > /dev/null 2>&1 || :
%preun -n castor-diskserver-manager
if [ "$1" = 0 ]; then
    /sbin/service diskmanagerd stop > /dev/null 2>&1 || :
    /sbin/chkconfig --del diskmanagerd
fi
%endif

%if ! %compiling_client
%package -n castor-lib-oracle
Summary: Cern Advanced mass STORage
Group: Application/Castor
Requires: oracle-instantclient-basic >= 11.2, castor-lib = %{version}-%{release}
BuildRequires:  oracle-instantclient-devel
%description -n castor-lib-oracle
castor (Cern Advanced STORage system) - Static and shared libraries for Oracle access
%files -n castor-lib-oracle
%defattr(-,root,root)
%ifarch x86_64
%attr(0640,root,root) /etc/castor/ORASTAGERCONFIG.example
%attr(-,root,root) /usr/lib64/libcastorcommonora.so.*
%attr(-,root,root) /usr/lib64/libcastorcnvs.so.*
%else
%attr(0640,root,root) /etc/castor/ORASTAGERCONFIG.example
%attr(-,root,root) /usr/lib/libcastorcommonora.so.*
%attr(-,root,root) /usr/lib/libcastorcnvs.so.*
%endif
%post -n castor-lib-oracle
# call to ldconfig after we installed new libraries
/sbin/ldconfig
%postun -n castor-lib-oracle
# call to ldconfig after we uninstalled libraries
/sbin/ldconfig
%endif

%package -n castor-ns-client
Summary: Cern Advanced mass STORage
Group: Application/Castor
Requires: castor-lib = %{version}-%{release}
%description -n castor-ns-client
castor (Cern Advanced STORage system) - Name server clients
%files -n castor-ns-client
%defattr(-,root,root)
%attr(0644,root,bin) %doc /usr/share/man/man1/nschclass.1castor.gz
%attr(0644,root,bin) %doc /usr/share/man/man1/nschmod.1castor.gz
%attr(0644,root,bin) %doc /usr/share/man/man1/nschown.1castor.gz
%attr(0644,root,bin) %doc /usr/share/man/man1/nsdelcomment.1castor.gz
%attr(0644,root,bin) %doc /usr/share/man/man1/nsdeleteclass.1castor.gz
%attr(0644,root,bin) %doc /usr/share/man/man1/nsdelsegment.1castor.gz
%attr(0644,root,bin) %doc /usr/share/man/man1/nsenterclass.1castor.gz
%attr(0644,root,bin) %doc /usr/share/man/man1/nsfind.1castor.gz
%attr(0644,root,bin) %doc /usr/share/man/man1/nsgetacl.1castor.gz
%attr(0644,root,bin) %doc /usr/share/man/man1/nsgetpath.1castor.gz
%attr(0644,root,bin) %doc /usr/share/man/man1/nslistclass.1castor.gz
%attr(0644,root,bin) %doc /usr/share/man/man1/nslisttape.1castor.gz
%attr(0644,root,bin) %doc /usr/share/man/man1/nsln.1castor.gz
%attr(0644,root,bin) %doc /usr/share/man/man1/nsls.1castor.gz
%attr(0644,root,bin) %doc /usr/share/man/man1/nsmkdir.1castor.gz
%attr(0644,root,bin) %doc /usr/share/man/man1/nsmodifyclass.1castor.gz
%attr(0644,root,bin) %doc /usr/share/man/man1/nsping.1castor.gz
%attr(0644,root,bin) %doc /usr/share/man/man1/nsrename.1castor.gz
%attr(0644,root,bin) %doc /usr/share/man/man1/nsrm.1castor.gz
%attr(0644,root,bin) %doc /usr/share/man/man1/nsrmdir.1castor.gz
%attr(0644,root,bin) %doc /usr/share/man/man1/nsrmvid.1castor.gz
%attr(0644,root,bin) %doc /usr/share/man/man1/nssetacl.1castor.gz
%attr(0644,root,bin) %doc /usr/share/man/man1/nssetchecksum.1castor.gz
%attr(0644,root,bin) %doc /usr/share/man/man1/nssetcomment.1castor.gz
%attr(0644,root,bin) %doc /usr/share/man/man1/nssetfsize.1castor.gz
%attr(0644,root,bin) %doc /usr/share/man/man1/nssetsegment.1castor.gz
%attr(0644,root,bin) %doc /usr/share/man/man1/nstouch.1castor.gz
%attr(0755,root,root) /usr/bin/nschclass
%attr(0755,root,root) /usr/bin/nschmod
%attr(0755,root,root) /usr/bin/nschown
%attr(0755,root,root) /usr/bin/nsdelcomment
%attr(0755,root,root) /usr/bin/nsdeleteclass
%attr(0755,root,root) /usr/bin/nsdelsegment
%attr(0755,root,root) /usr/bin/nsenterclass
%attr(0755,root,root) /usr/bin/nsfind
%attr(0755,root,root) /usr/bin/nsgetacl
%attr(0755,root,root) /usr/bin/nsgetpath
%attr(0755,root,root) /usr/bin/nslistclass
%attr(0755,root,root) /usr/bin/nslisttape
%attr(0755,root,root) /usr/bin/nsln
%attr(0755,root,root) /usr/bin/nsls
%attr(0755,root,root) /usr/bin/nsmkdir
%attr(0755,root,root) /usr/bin/nsmodifyclass
%attr(0755,root,root) /usr/bin/nsping
%attr(0755,root,root) /usr/bin/nsrename
%attr(0755,root,root) /usr/bin/nsrm
%attr(0755,root,root) /usr/bin/nsrmdir
%attr(0755,root,root) /usr/bin/nsrmvid
%attr(0755,root,root) /usr/bin/nssetchecksum
%attr(0755,root,root) /usr/bin/nssetacl
%attr(0755,root,root) /usr/bin/nssetcomment
%attr(0755,root,root) /usr/bin/nssetfsize
%attr(0755,root,root) /usr/bin/nssetsegment
%attr(0755,root,root) /usr/bin/nstouch

%if ! %compiling_client
%package -n castor-ns-server
Summary: Cern Advanced mass STORage
Group: Application/Castor
Requires: logrotate, oracle-instantclient-basic >= 11.2, castor-lib = %{version}-%{release}
BuildRequires:  oracle-instantclient-precomp
%description -n castor-ns-server
castor (Cern Advanced STORage system) - Name server daemon
%files -n castor-ns-server
%defattr(-,root,root)
%attr(0644,root,bin) %doc /usr/share/man/man8/nsd.8castor.gz
%attr(-,root,bin) %dir /var/log/castor
%attr(0640,root,root) /etc/castor/NSCONFIG.example
%attr(0755,root,root) /etc/init.d/nsd
%attr(0644,root,root) /etc/sysconfig/nsd.example
%attr(0644,root,root) /etc/sysconfig/nsd.normal.example
%attr(0644,root,root) /etc/sysconfig/nsd.secure.example
%attr(0644,root,root) %config(noreplace) /etc/logrotate.d/castor-ns-server
%attr(0755,root,root) /usr/bin/nsd
%post -n castor-ns-server
/usr/sbin/groupadd -g 1474 st > /dev/null 2>&1 || :
/usr/sbin/useradd -s /bin/nologin -c "Stager Staging System" -u 14029 -g 1474 stage > /dev/null 2>&1 || :
/sbin/chkconfig --add nsd
/sbin/service nsd condrestart > /dev/null 2>&1 || :
%preun -n castor-ns-server
if [ "$1" = 0 ]; then
    /sbin/service nsd stop > /dev/null 2>&1 || :
    /sbin/chkconfig --del nsd
fi
%endif

%package -n castor-rfio-client
Summary: Cern Advanced mass STORage
Group: Application/Castor
Requires: castor-lib = %{version}-%{release}
%description -n castor-rfio-client
castor (Cern Advanced STORage system) - RFIO clients
%files -n castor-rfio-client
%defattr(-,root,root)
%attr(0644,root,bin) %doc /usr/share/man/man1/rfcat.1castor.gz
%attr(0644,root,bin) %doc /usr/share/man/man1/rfchmod.1castor.gz
%attr(0644,root,bin) %doc /usr/share/man/man1/rfcp.1castor.gz
%attr(0644,root,bin) %doc /usr/share/man/man1/rfdir.1castor.gz
%attr(0644,root,bin) %doc /usr/share/man/man1/rfmkdir.1castor.gz
%attr(0644,root,bin) %doc /usr/share/man/man1/rfrename.1castor.gz
%attr(0644,root,bin) %doc /usr/share/man/man1/rfrm.1castor.gz
%attr(0755,root,root) /usr/bin/rfcat
%attr(0755,root,root) /usr/bin/rfchmod
%attr(0755,root,root) /usr/bin/rfcp
%attr(0755,root,root) /usr/bin/rfdir
%attr(0755,root,root) /usr/bin/rfmkdir
%attr(0755,root,root) /usr/bin/rfrename
%attr(0755,root,root) /usr/bin/rfrm
%attr(0755,root,root) /usr/bin/rfstat

%if ! %compiling_client
%package -n castor-rfio-server
Summary: Cern Advanced mass STORage
Group: Application/Castor
Requires: logrotate, castor-lib = %{version}-%{release}
BuildRequires:  xfsprogs-devel, libattr-devel, zlib-devel
%description -n castor-rfio-server
castor (Cern Advanced STORage system) - RFIO server
%files -n castor-rfio-server
%defattr(-,root,root)
%attr(0644,root,bin) %doc /usr/share/man/man1/rfiod.1castor.gz
%attr(-,root,bin) %dir /var/log/castor
%attr(-,root,bin) %dir /var/lib/rfiod
%attr(0755,root,root) /etc/init.d/rfiod
%attr(0644,root,root) /etc/sysconfig/rfiod.example
%attr(0644,root,root) %config(noreplace) /etc/logrotate.d/castor-rfio-server
%attr(0755,root,root) /usr/bin/rfiod
%post -n castor-rfio-server
/usr/sbin/groupadd -g 1474 st > /dev/null 2>&1 || :
/usr/sbin/useradd -s /bin/nologin -c "Stager Staging System" -u 14029 -g 1474 stage > /dev/null 2>&1 || :
/sbin/chkconfig --add rfiod
/sbin/service rfiod condrestart > /dev/null 2>&1 || :
%preun -n castor-rfio-server
if [ "$1" = 0 ]; then
    /sbin/service rfiod stop > /dev/null 2>&1 || :
    /sbin/chkconfig --del rfiod
fi
%endif

%if ! %compiling_client
%package -n castor-rh-server
Summary: Cern Advanced mass STORage
Group: Application/Castor
Requires: logrotate, libmemcached >= 0.34, castor-lib-oracle = %{version}-%{release}, castor-lib = %{version}-%{release}
BuildRequires:  libmemcached-devel >= 0.34
%description -n castor-rh-server
castor (Cern Advanced STORage system) - Request Handler server
%files -n castor-rh-server
%defattr(-,root,root)
%attr(0644,root,bin) %doc /usr/share/man/man8/rhd.8castor.gz
%attr(-,root,bin) %dir /var/log/castor
%attr(0755,stage,st) %dir /var/spool/castor
%attr(0755,root,root) /etc/init.d/rhd
%attr(0644,root,root) /etc/sysconfig/rhd.example
%attr(0644,root,root) %config(noreplace) /etc/logrotate.d/castor-rh-server
%attr(0755,root,root) /usr/bin/rhd
%post -n castor-rh-server
/usr/sbin/groupadd -g 1474 st > /dev/null 2>&1 || :
/usr/sbin/useradd -s /bin/nologin -c "Stager Staging System" -u 14029 -g 1474 stage > /dev/null 2>&1 || :
/sbin/chkconfig --add rhd
/sbin/service rhd condrestart > /dev/null 2>&1 || :
%preun -n castor-rh-server
if [ "$1" = 0 ]; then
    /sbin/service rhd stop > /dev/null 2>&1 || :
    /sbin/chkconfig --del rhd
fi
%endif

%if ! %compiling_client
%package -n castor-rmc-server
Summary: Cern Advanced mass STORage
Group: Application/Castor
Requires: logrotate, castor-lib = %{version}-%{release}
%description -n castor-rmc-server
castor (Cern Advanced STORage system) - Remote Media Controller server
%files -n castor-rmc-server
%defattr(-,root,root)
%attr(0644,root,bin) %doc /usr/share/man/man8/rmcd.8castor.gz
%attr(-,root,bin) %dir /var/log/castor
%attr(0755,root,root) /etc/init.d/rmcd
%attr(0644,root,root) /etc/sysconfig/rmcd.example
%attr(0644,root,root) %config(noreplace) /etc/logrotate.d/castor-rmc-server
%attr(0755,root,root) /usr/bin/rmcd
%post -n castor-rmc-server
/usr/sbin/groupadd -g 1474 st > /dev/null 2>&1 || :
/usr/sbin/useradd -s /bin/nologin -c "Stager Staging System" -u 14029 -g 1474 stage > /dev/null 2>&1 || :
/sbin/chkconfig --add rmcd
/sbin/service rmcd condrestart > /dev/null 2>&1 || :
%preun -n castor-rmc-server
if [ "$1" = 0 ]; then
    /sbin/service rmcd stop > /dev/null 2>&1 || :
    /sbin/chkconfig --del rmcd
fi
%endif

%if ! %compiling_client
%package -n castor-rmc-client
Summary: Cern Advanced mass STORage
Group: Application/Castor
Requires: castor-lib = %{version}-%{release}
%description -n castor-rmc-client
castor (Cern Advanced STORage system) - Remote Media Controller clients
%files -n castor-rmc-client
%defattr(-,root,root)
%attr(0644,root,bin) %doc /usr/share/man/man1/smc.1castor.gz
%attr(6755,root,root) /usr/bin/smc
%endif

%if ! %compiling_client
%package -n castor-rtcopy-server
Summary: Cern Advanced mass STORage
Group: Application/Castor
Requires: logrotate, zlib-devel, castor-lib = %{version}-%{release}
%description -n castor-rtcopy-server
castor (Cern Advanced STORage system) - Remote Tape Copy server running on a tape server
%files -n castor-rtcopy-server
%defattr(-,root,root)
%attr(0644,root,bin) %doc /usr/share/man/man1/rtcpd.1castor.gz
%attr(-,root,bin) %dir /var/log/castor
%attr(-,root,bin) %dir /var/lib/castor
%attr(0755,root,root) /etc/init.d/rtcpd
%attr(0644,root,root) /etc/sysconfig/rtcpd.example
%attr(0644,root,root) %config(noreplace) /etc/logrotate.d/castor-rtcopy-server
%attr(0755,root,root) /usr/bin/rtcpd
%post -n castor-rtcopy-server
/usr/sbin/groupadd -g 1474 st > /dev/null 2>&1 || :
/usr/sbin/useradd -s /bin/nologin -c "Stager Staging System" -u 14029 -g 1474 stage > /dev/null 2>&1 || :
/sbin/chkconfig --add rtcpd
/sbin/service rtcpd condrestart > /dev/null 2>&1 || :
%preun -n castor-rtcopy-server
if [ "$1" = 0 ]; then
    /sbin/service rtcpd stop > /dev/null 2>&1 || :
    /sbin/chkconfig --del rtcpd
fi
%endif

%package -n castor-stager-client
Summary: Cern Advanced mass STORage
Group: Application/Castor
Requires: castor-lib = %{version}-%{release}
%description -n castor-stager-client
castor (Cern Advanced STORage system) - Stager clients
%files -n castor-stager-client
%defattr(-,root,root)
%attr(0644,root,bin) %doc /usr/share/man/man1/castor.1castor.gz
%attr(0644,root,bin) %doc /usr/share/man/man1/stager_get.1castor.gz
%attr(0644,root,bin) %doc /usr/share/man/man1/stager_update.1castor.gz
%attr(0644,root,bin) %doc /usr/share/man/man1/stager_put.1castor.gz
%attr(0644,root,bin) %doc /usr/share/man/man1/stager_putdone.1castor.gz
%attr(0644,root,bin) %doc /usr/share/man/man1/stager_qry.1castor.gz
%attr(0644,root,bin) %doc /usr/share/man/man1/stager_rm.1castor.gz
%attr(0644,root,bin) %doc /usr/share/man/man1/stager_setfilegcweight.1castor.gz
%attr(0644,root,bin) %doc /usr/share/man/man1/stager_addprivilege.1castor.gz
%attr(0644,root,bin) %doc /usr/share/man/man1/stager_removeprivilege.1castor.gz
%attr(0644,root,bin) %doc /usr/share/man/man1/stager_listprivileges.1castor.gz
%attr(0755,root,root) /usr/bin/stager_get
%attr(0755,root,root) /usr/bin/stager_update
%attr(0755,root,root) /usr/bin/stager_put
%attr(0755,root,root) /usr/bin/stager_putdone
%attr(0755,root,root) /usr/bin/stager_qry
%attr(0755,root,root) /usr/bin/stager_rm
%attr(0755,root,root) /usr/bin/stager_setfilegcweight
%attr(0755,root,root) /usr/bin/stager_addprivilege
%attr(0755,root,root) /usr/bin/stager_removeprivilege
%attr(0755,root,root) /usr/bin/stager_listprivileges
%attr(0755,root,root) /usr/bin/castor

%if ! %compiling_client
%package -n castor-stager-server
Summary: Cern Advanced mass STORage
Group: Application/Castor
Requires: logrotate, castor-lib-oracle = %{version}-%{release}, castor-lib = %{version}-%{release}
%description -n castor-stager-server
castor (Cern Advanced STORage system) - Stager server
%files -n castor-stager-server
%defattr(-,root,root)
%attr(0644,root,bin) %doc /usr/share/man/man8/stagerd.8castor.gz
%attr(-,root,bin) %dir /var/log/castor
%attr(0755,stage,st) %dir /var/spool/castor
%attr(0755,root,root) /etc/init.d/stagerd
%attr(0644,root,root) /etc/sysconfig/stagerd.example
%attr(0644,root,root) %config(noreplace) /etc/logrotate.d/castor-stager-server
%attr(0755,root,root) /usr/bin/stagerd
%post -n castor-stager-server
/usr/sbin/groupadd -g 1474 st > /dev/null 2>&1 || :
/usr/sbin/useradd -s /bin/nologin -c "Stager Staging System" -u 14029 -g 1474 stage > /dev/null 2>&1 || :
/sbin/chkconfig --add stagerd
/sbin/service stagerd condrestart > /dev/null 2>&1 || :
%preun -n castor-stager-server
if [ "$1" = 0 ]; then
    /sbin/service stagerd stop > /dev/null 2>&1 || :
    /sbin/chkconfig --del stagerd
fi
%endif

%if ! %compiling_client
%package -n castor-tape-tools
Summary: Cern Advanced mass STORage
Group: Application/Castor
Requires: castor-lib = %{version}-%{release}
%description -n castor-tape-tools
castor (Cern Advanced STORage system) - Tape tools
%files -n castor-tape-tools
%defattr(-,root,root)
%attr(0644,root,bin) %doc /usr/share/man/man1/tpstat.1castor.gz
%attr(0644,root,bin) %doc /usr/share/man/man1/tpconfig.1castor.gz
%attr(0755,root,root) /usr/bin/tpconfig
%attr(0755,root,root) /usr/bin/tpstat
%endif

%if ! %compiling_client
%package -n castor-tape-server
Summary: Cern Advanced mass STORage
Group: Application/Castor
Requires: logrotate, stk-ssi, castor-lib = %{version}-%{release}
BuildRequires:  stk-ssi-devel, stk-ssi
Conflicts: castor-tape-server-nostk
%description -n castor-tape-server
castor (Cern Advanced STORage system) - Tape server
%files -n castor-tape-server
%defattr(-,root,root)
%attr(0644,root,bin) %doc /usr/share/man/man8/taped.8castor.gz
%attr(0644,root,bin) %doc /usr/share/man/man1/tplabel.1castor.gz
%attr(-,root,bin) %dir /var/log/castor
%attr(0640,root,root) /etc/castor/TPCONFIG.example
%attr(0755,root,root) /etc/init.d/taped
%attr(0644,root,root) /etc/sysconfig/taped.example
%attr(0644,root,root) %config(noreplace) /etc/logrotate.d/castor-tape-server
%attr(0755,root,root) /usr/bin/confdrive
%attr(0755,root,root) /usr/bin/mounttape
%attr(0755,root,root) /usr/bin/posovl
%attr(0755,root,root) /usr/bin/rlstape
%attr(0755,root,root) /usr/bin/taped
%attr(0755,root,root) /usr/bin/tplabel
%post -n castor-tape-server
/usr/sbin/groupadd -g 1474 st > /dev/null 2>&1 || :
/usr/sbin/useradd -s /bin/nologin -c "Stager Staging System" -u 14029 -g 1474 stage > /dev/null 2>&1 || :
/sbin/chkconfig --add taped
/sbin/service taped condrestart > /dev/null 2>&1 || :
%preun -n castor-tape-server
if [ "$1" = 0 ]; then
    /sbin/service taped stop > /dev/null 2>&1 || :
    /sbin/chkconfig --del taped
fi
%endif

%if ! %compiling_client
%package -n castor-tape-server-nostk
Summary: Cern Advanced mass STORage
Group: Application/Castor
Requires: logrotate, castor-lib = %{version}-%{release}
%description -n castor-tape-server-nostk
castor (Cern Advanced STORage system) - Tape server
%files -n castor-tape-server-nostk
%defattr(-,root,root)
%attr(0644,root,bin) %doc /usr/share/man/man8/taped.8castor.gz
%attr(0644,root,bin) %doc /usr/share/man/man1/tplabel.1castor.gz
%attr(-,root,bin) %dir /var/log/castor
%attr(0640,root,root) /etc/castor/TPCONFIG.example
%attr(0755,root,root) /etc/init.d/taped
%attr(0644,root,root) /etc/sysconfig/taped.example
%attr(0644,root,root) %config(noreplace) /etc/logrotate.d/castor-tape-server
%attr(0755,root,root) /usr/bin/confdrive
%attr(0755,root,root) /usr/bin/mounttape-nostk
%attr(0755,root,root) /usr/bin/posovl
%attr(0755,root,root) /usr/bin/rlstape-nostk
%attr(0755,root,root) /usr/bin/taped
%attr(0755,root,root) /usr/bin/tplabel
%post -n castor-tape-server-nostk
/bin/ln -s -f /usr/bin/mounttape-nostk /usr/bin/mounttape
/bin/ln -s -f /usr/bin/rlstape-nostk /usr/bin/rlstape
/sbin/chkconfig --add taped
/sbin/service taped condrestart > /dev/null 2>&1 || :
%preun -n castor-tape-server-nostk
if [ "$1" = 0 ]; then
    /sbin/service taped stop > /dev/null 2>&1 || :
    /sbin/chkconfig --del taped
    /bin/rm -f /usr/bin/mounttape
    /bin/rm -f /usr/bin/rlstape
fi
%endif

%package -n castor-upv-client
Summary: Cern Advanced mass STORage
Group: Application/Castor
Requires: castor-lib = %{version}-%{release}
%description -n castor-upv-client
castor (Cern Advanced STORage system) - User Privilege clients
%files -n castor-upv-client
%defattr(-,root,root)
%attr(0644,root,bin) %doc /usr/share/man/man1/Cupvadd.1castor.gz
%attr(0644,root,bin) %doc /usr/share/man/man1/Cupvcheck.1castor.gz
%attr(0644,root,bin) %doc /usr/share/man/man1/Cupvdelete.1castor.gz
%attr(0644,root,bin) %doc /usr/share/man/man1/Cupvlist.1castor.gz
%attr(0644,root,bin) %doc /usr/share/man/man1/Cupvmodify.1castor.gz
%attr(0755,root,root) /usr/bin/Cupvadd
%attr(0755,root,root) /usr/bin/Cupvcheck
%attr(0755,root,root) /usr/bin/Cupvdelete
%attr(0755,root,root) /usr/bin/Cupvlist
%attr(0755,root,root) /usr/bin/Cupvmodify

%if ! %compiling_client
%package -n castor-upv-server
Summary: Cern Advanced mass STORage
Group: Application/Castor
Requires: logrotate, oracle-instantclient-basic >= 11.2, castor-lib = %{version}-%{release}
BuildRequires:  oracle-instantclient-precomp
%description -n castor-upv-server
castor (Cern Advanced STORage system) - User Privilege server
%files -n castor-upv-server
%defattr(-,root,root)
%attr(0644,root,bin) %doc /usr/share/man/man8/cupvd.8castor.gz
%attr(-,root,bin) %dir /var/log/castor
%attr(0640,root,root) /etc/castor/CUPVCONFIG.example
%attr(0755,root,root) /etc/init.d/cupvd
%attr(0644,root,root) /etc/sysconfig/cupvd.example
%attr(0644,root,root) %config(noreplace) /etc/logrotate.d/castor-upv-server
%attr(0755,root,root) /usr/bin/cupvd
%post -n castor-upv-server
/usr/sbin/groupadd -g 1474 st > /dev/null 2>&1 || :
/usr/sbin/useradd -s /bin/nologin -c "Stager Staging System" -u 14029 -g 1474 stage > /dev/null 2>&1 || :
/sbin/chkconfig --add cupvd
/sbin/service cupvd condrestart > /dev/null 2>&1 || :
%preun -n castor-upv-server
if [ "$1" = 0 ]; then
    /sbin/service cupvd stop > /dev/null 2>&1 || :
    /sbin/chkconfig --del cupvd
fi
%endif

%package -n castor-vdqm2-client
Summary: Cern Advanced mass STORage
Group: Application/Castor
Requires: castor-lib = %{version}-%{release}
Obsoletes: castor-vdqm-client
%description -n castor-vdqm2-client
castor (Cern Advanced STORage system) - Volume Drive and Queue Manager clients version 2
%files -n castor-vdqm2-client
%defattr(-,root,root)
%attr(0644,root,bin) %doc /usr/share/man/man1/vdqm_admin.1castor.gz
%attr(0644,root,bin) %doc /usr/share/man/man1/showqueues.1castor.gz
%attr(0755,root,root) /usr/bin/showqueues
%attr(0755,root,root) /usr/bin/vdqm_admin

%if ! %compiling_client
%package -n castor-vdqm2-server
Summary: Cern Advanced mass STORage
Group: Application/Castor
Requires: logrotate, castor-lib-oracle = %{version}-%{release}, castor-vdqm2-lib-oracle = %{version}-%{release}, castor-lib = %{version}-%{release}
Obsoletes: castor-vdqm-server
%description -n castor-vdqm2-server
castor (Cern Advanced STORage system) - Volume Drive and Queue Manager server version 2
%files -n castor-vdqm2-server
%defattr(-,root,root)
%attr(0644,root,bin) %doc /usr/share/man/man8/vdqmd.8castor.gz
%attr(-,root,bin) %dir /var/log/castor
%attr(0755,root,root) /etc/init.d/vdqmd
%attr(0644,root,root) /etc/sysconfig/vdqmd.example
%attr(0644,root,root) %config(noreplace) /etc/logrotate.d/castor-vdqm2-server
%attr(0755,root,root) /usr/bin/vdqmd
%attr(0640,root,root) /etc/castor/ORAVDQMCONFIG.example
%post -n castor-vdqm2-server
/usr/sbin/groupadd -g 1474 st > /dev/null 2>&1 || :
/usr/sbin/useradd -s /bin/nologin -c "Stager Staging System" -u 14029 -g 1474 stage > /dev/null 2>&1 || :
/sbin/chkconfig --add vdqmd
/sbin/service vdqmd condrestart > /dev/null 2>&1 || :
%preun -n castor-vdqm2-server
if [ "$1" = 0 ]; then
    /sbin/service vdqmd stop > /dev/null 2>&1 || :
    /sbin/chkconfig --del vdqmd
fi
%endif

%if ! %compiling_client
%package -n castor-vdqm2-lib-oracle
Summary: Cern Advanced mass STORage
Group: Application/Castor
Requires: logrotate, castor-lib-oracle = %{version}-%{release}, castor-lib = %{version}-%{release}
%description -n castor-vdqm2-lib-oracle
castor (Cern Advanced STORage system) - Volume Drive and Queue Manager server version 2 library
%files -n castor-vdqm2-lib-oracle
%defattr(-,root,root)
%ifarch x86_64
%attr(-,root,root) /usr/lib64/libcastorvdqmora.so.*
%else
%attr(-,root,root) /usr/lib/libcastorvdqmora.so.*
%endif
%post -n castor-vdqm2-lib-oracle
# call to ldconfig after we installed new libraries
/sbin/ldconfig
%postun -n castor-vdqm2-lib-oracle
# call to ldconfig after we uninstalled libraries
/sbin/ldconfig
%endif

%package -n castor-vmgr-client
Summary: Cern Advanced mass STORage
Group: Application/Castor
Requires: castor-lib = %{version}-%{release}
%description -n castor-vmgr-client
castor (Cern Advanced STORage system) - Volume Manager clients
%files -n castor-vmgr-client
%defattr(-,root,root)
%attr(0644,root,bin) %doc /usr/share/man/man1/vmgr.1castor.gz
%attr(0644,root,bin) %doc /usr/share/man/man1/vmgrdeletedenmap.1castor.gz
%attr(0644,root,bin) %doc /usr/share/man/man1/vmgrdeletedgnmap.1castor.gz
%attr(0644,root,bin) %doc /usr/share/man/man1/vmgrdeletelibrary.1castor.gz
%attr(0644,root,bin) %doc /usr/share/man/man1/vmgrdeletemodel.1castor.gz
%attr(0644,root,bin) %doc /usr/share/man/man1/vmgrdeletepool.1castor.gz
%attr(0644,root,bin) %doc /usr/share/man/man1/vmgrdeletetape.1castor.gz
%attr(0644,root,bin) %doc /usr/share/man/man1/vmgrdeltag.1castor.gz
%attr(0644,root,bin) %doc /usr/share/man/man1/vmgrenterdenmap.1castor.gz
%attr(0644,root,bin) %doc /usr/share/man/man1/vmgrenterdgnmap.1castor.gz
%attr(0644,root,bin) %doc /usr/share/man/man1/vmgrenterlibrary.1castor.gz
%attr(0644,root,bin) %doc /usr/share/man/man1/vmgrentermodel.1castor.gz
%attr(0644,root,bin) %doc /usr/share/man/man1/vmgrenterpool.1castor.gz
%attr(0644,root,bin) %doc /usr/share/man/man1/vmgrentertape.1castor.gz
%attr(0644,root,bin) %doc /usr/share/man/man1/vmgrgettag.1castor.gz
%attr(0644,root,bin) %doc /usr/share/man/man1/vmgrlistdenmap.1castor.gz
%attr(0644,root,bin) %doc /usr/share/man/man1/vmgrlistdgnmap.1castor.gz
%attr(0644,root,bin) %doc /usr/share/man/man1/vmgrlistlibrary.1castor.gz
%attr(0644,root,bin) %doc /usr/share/man/man1/vmgrlistmodel.1castor.gz
%attr(0644,root,bin) %doc /usr/share/man/man1/vmgrlistpool.1castor.gz
%attr(0644,root,bin) %doc /usr/share/man/man1/vmgrlisttape.1castor.gz
%attr(0644,root,bin) %doc /usr/share/man/man1/vmgrmodifylibrary.1castor.gz
%attr(0644,root,bin) %doc /usr/share/man/man1/vmgrmodifypool.1castor.gz
%attr(0644,root,bin) %doc /usr/share/man/man1/vmgrmodifytape.1castor.gz
%attr(0644,root,bin) %doc /usr/share/man/man1/vmgrsettag.1castor.gz
%attr(0755,root,root) /usr/bin/vmgrdeletedenmap
%attr(0755,root,root) /usr/bin/vmgrdeletedgnmap
%attr(0755,root,root) /usr/bin/vmgrdeletelibrary
%attr(0755,root,root) /usr/bin/vmgrdeletemodel
%attr(0755,root,root) /usr/bin/vmgrdeletepool
%attr(0755,root,root) /usr/bin/vmgrdeletetape
%attr(0755,root,root) /usr/bin/vmgrdeltag
%attr(0755,root,root) /usr/bin/vmgrenterdenmap
%attr(0755,root,root) /usr/bin/vmgrenterdgnmap
%attr(0755,root,root) /usr/bin/vmgrenterlibrary
%attr(0755,root,root) /usr/bin/vmgrentermodel
%attr(0755,root,root) /usr/bin/vmgrenterpool
%attr(0755,root,root) /usr/bin/vmgrentertape
%attr(0755,root,root) /usr/bin/vmgrgettag
%attr(0755,root,root) /usr/bin/vmgrlistdenmap
%attr(0755,root,root) /usr/bin/vmgrlistdgnmap
%attr(0755,root,root) /usr/bin/vmgrlistlibrary
%attr(0755,root,root) /usr/bin/vmgrlistmodel
%attr(0755,root,root) /usr/bin/vmgrlistpool
%attr(0755,root,root) /usr/bin/vmgrlisttape
%attr(0755,root,root) /usr/bin/vmgrmodifylibrary
%attr(0755,root,root) /usr/bin/vmgrmodifypool
%attr(0755,root,root) /usr/bin/vmgrmodifytape
%attr(0755,root,root) /usr/bin/vmgrsettag

%if ! %compiling_client
%package -n castor-vmgr-server
Summary: Cern Advanced mass STORage
Group: Application/Castor
Requires: logrotate, oracle-instantclient-basic >= 11.2, castor-lib = %{version}-%{release}
BuildRequires:  oracle-instantclient-precomp
%description -n castor-vmgr-server
castor (Cern Advanced STORage system) - Volume Manager server
%files -n castor-vmgr-server
%defattr(-,root,root)
%attr(0644,root,bin) %doc /usr/share/man/man8/vmgrd.8castor.gz
%attr(-,root,bin) %dir /var/log/castor
%attr(0640,root,root) /etc/castor/VMGRCONFIG.example
%attr(0755,root,root) /etc/init.d/vmgrd
%attr(0644,root,root) /etc/sysconfig/vmgrd.example
%attr(0644,root,root) %config(noreplace) /etc/logrotate.d/castor-vmgr-server
%attr(0755,root,root) /usr/bin/vmgrd
%post -n castor-vmgr-server
/usr/sbin/groupadd -g 1474 st > /dev/null 2>&1 || :
/usr/sbin/useradd -s /bin/nologin -c "Stager Staging System" -u 14029 -g 1474 stage > /dev/null 2>&1 || :
/sbin/chkconfig --add vmgrd
/sbin/service vmgrd condrestart > /dev/null 2>&1 || :
%preun -n castor-vmgr-server
if [ "$1" = 0 ]; then
    /sbin/service vmgrd stop > /dev/null 2>&1 || :
    /sbin/chkconfig --del vmgrd
fi
%endif

%if ! %compiling_client
%package -n castor-lib-tape
Summary: Cern Advanced mass STORage
Group: Application/Castor
Requires: castor-lib = %{version}-%{release}
BuildRequires:  python-devel
Obsoletes: castor-lib-policy,castor-lib-tapeutils
%description -n castor-lib-tape
castor (Cern Advanced STORage system) - Shared utilities library for castor tape servers and command-line tools
%files -n castor-lib-tape
%defattr(-,root,root)
%ifarch x86_64
%attr(-,root,root) /usr/lib64/libcastorrmc.so.*
%attr(-,root,root) /usr/lib64/libcastortape.so.*
%attr(-,root,root) /usr/lib64/libcastortapebridge.so.*
%attr(-,root,root) /usr/lib64/libcastortapegatewayprotocol.so.*
%attr(-,root,root) /usr/lib64/libcastortapelegacymsg.so.*
%attr(-,root,root) /usr/lib64/libcastortapenet.so.*
%attr(-,root,root) /usr/lib64/libcastortapeutils.so.*
%else
%attr(-,root,root) /usr/lib/libcastorrmc.so.*
%attr(-,root,root) /usr/lib/libcastortape.so.*
%attr(-,root,root) /usr/lib/libcastortapebridge.so.*
%attr(-,root,root) /usr/lib/libcastortapegatewayprotocol.so.*
%attr(-,root,root) /usr/lib/libcastortapelegacymsg.so.*
%attr(-,root,root) /usr/lib/libcastortapenet.so.*
%attr(-,root,root) /usr/lib/libcastortapeutils.so.*
%endif
%post -n castor-lib-tape
# call to ldconfig after we installed new libraries
/sbin/ldconfig
%postun -n castor-lib-tape
# call to ldconfig after we uninstalled libraries
/sbin/ldconfig
%endif

%if ! %compiling_client
%package -n castor-gridftp-dsi-common
Summary: Cern Advanced mass STORage
Group: Application/Castor
Requires: castor-lib = %{version}-%{release}
%description -n castor-gridftp-dsi-common
castor (Cern Advanced STORage system) - Commonnalities between internal and external CASTOR2 gridftp2 DSI module
%files -n castor-gridftp-dsi-common
%defattr(-,root,root)
%attr(0644,root,root) %config(noreplace) /etc/logrotate.d/castor-gridftp-dsi-common
%endif

%if ! %compiling_client
%package -n castor-gridftp-dsi-int
Summary: Cern Advanced mass STORage
Group: Application/Castor
Requires: globus-gridftp-server-progs, globus-common, castor-gridftp-dsi-common
BuildRequires:  libattr-devel, zlib-devel, globus-gridftp-server-devel, globus-common-devel
%description -n castor-gridftp-dsi-int
castor (Cern Advanced STORage system) - Internal CASTOR2 gridftp2 DSI module
%files -n castor-gridftp-dsi-int
%defattr(-,root,root)
%attr(-,root,bin) %dir /var/log
%ifarch x86_64
%attr(0755,root,root) /usr/lib64/libglobus_gridftp_server_CASTOR2int.so*
%else
%attr(0755,root,root) /usr/lib/libglobus_gridftp_server_CASTOR2int.so*
%endif
%post -n castor-gridftp-dsi-int
/bin/touch /var/log/gridftp.log
/bin/touch /var/log/globus-gridftp.log
/bin/chown stage:st /var/log/gridftp.log
/bin/chown stage:st /var/log/globus-gridftp.log
%endif

%if ! %compiling_client
%package -n castor-gridftp-dsi-ext
Summary: Cern Advanced mass STORage
Group: Application/Castor
Requires: xinetd, globus-gridftp-server-progs, globus-common, castor-gridftp-dsi-common
BuildRequires:  globus-gridftp-server-devel, globus-common-devel
%description -n castor-gridftp-dsi-ext
castor (Cern Advanced STORage system) - External CASTOR2 gridftp2 DSI module
%files -n castor-gridftp-dsi-ext
%defattr(-,root,root)
%attr(-,root,bin) %dir /var/log
%ifarch x86_64
%attr(0755,root,root) /usr/lib64/libglobus_gridftp_server_CASTOR2ext.so*
%attr(0644,root,root) %config(noreplace) /etc/xinetd.d/gsiftp
%else
%attr(0755,root,root) /usr/lib/libglobus_gridftp_server_CASTOR2ext.so*
%attr(0644,root,root) %config(noreplace) /etc/xinetd.d/gsiftp
%endif
%post -n castor-gridftp-dsi-ext
if [ "`grep gsiftp /etc/services`" = "" ]; then 
    echo "gsiftp          2811/tcp # gridftp server port" >> /etc/services
fi
/sbin/service xinetd condrestart > /dev/null 2>&1 || :
%postun -n castor-gridftp-dsi-ext
/sbin/service xinetd reload > /dev/null 2>&1 || :
%endif

%if ! %compiling_client
%package -n castor-tapebridge-server
Summary: Cern Advanced mass STORage
Group: Application/Castor
Requires: logrotate, castor-rtcopy-server, castor-lib-tape = %{version}-%{release}
BuildRequires:  cppunit-devel
Obsoletes: castor-aggregator-server
%description -n castor-tapebridge-server
castor (Cern Advanced STORage system) - Tape Bridge Daemon
%files -n castor-tapebridge-server
%defattr(-,root,root)
%attr(0644,root,bin) %doc /usr/share/man/man8/tapebridged.8castor.gz
%attr(-,root,bin) %dir /var/log/castor
%attr(0755,root,root) /usr/bin/tapebridged
%attr(0644,root,root) /etc/sysconfig/tapebridged.example
%attr(0755,root,root) /etc/init.d/tapebridged
%attr(0644,root,root) %config(noreplace) /etc/logrotate.d/castor-tapebridge-server
%post -n castor-tapebridge-server
/usr/sbin/groupadd -g 1474 st > /dev/null 2>&1 || :
/usr/sbin/useradd -s /bin/nologin -c "Stager Staging System" -u 14029 -g 1474 stage > /dev/null 2>&1 || :
/sbin/chkconfig --add tapebridged
/sbin/service tapebridged condrestart > /dev/null 2>&1 || :
%preun -n castor-tapebridge-server
if [ "$1" = 0 ]; then
    /sbin/service tapebridged stop > /dev/null 2>&1 || :
    /sbin/chkconfig --del tapebridged
fi
%endif

%if ! %compiling_client
%package -n castor-tapebridge-client
Summary: Cern Advanced mass STORage
Group: Application/Castor
Requires: logrotate, castor-lib-tape = %{version}-%{release}
Obsoletes: castor-aggregator-client
%description -n castor-tapebridge-client
castor (Cern Advanced STORage system) - Tape Bridge Clients
%files -n castor-tapebridge-client
%defattr(-,root,root)
%attr(0644,root,bin) %doc /usr/share/man/man1/dumptp.1castor.gz
%attr(0644,root,bin) %doc /usr/share/man/man1/readtp.1castor.gz
%attr(0644,root,bin) %doc /usr/share/man/man1/writetp.1castor.gz
%attr(0755,root,root) /usr/bin/dumptp
%attr(0755,root,root) /usr/bin/readtp
%attr(0755,root,root) /usr/bin/writetp
%endif

%if ! %compiling_client
%package -n castor-tapegateway-server
Summary: Cern Advanced mass STORage
Group: Application/Castor
Requires: logrotate, castor-lib-oracle = %{version}-%{release}, castor-lib-tape = %{version}-%{release}
%description -n castor-tapegateway-server
castor (Cern Advanced STORage system) - Tape Gateway Daemon
%files -n castor-tapegateway-server
%defattr(-,root,root)
%attr(0644,root,bin) %doc /usr/share/man/man8/tapegatewayd.8castor.gz
%attr(-,root,bin) %dir /var/log/castor
%attr(0755,root,root) /etc/init.d/tapegatewayd
%attr(0644,root,root) /etc/sysconfig/tapegatewayd.example
%attr(0644,root,root) %config(noreplace) /etc/logrotate.d/castor-tapegateway-server
%attr(0755,root,root) /usr/bin/tapegatewayd
%post -n castor-tapegateway-server
/usr/sbin/groupadd -g 1474 st > /dev/null 2>&1 || :
/usr/sbin/useradd -s /bin/nologin -c "Stager Staging System" -u 14029 -g 1474 stage > /dev/null 2>&1 || :
/sbin/chkconfig --add tapegatewayd
/sbin/service tapegatewayd condrestart > /dev/null 2>&1 || :
%preun -n castor-tapegateway-server
if [ "$1" = 0 ]; then
    /sbin/service tapegatewayd stop > /dev/null 2>&1 || :
    /sbin/chkconfig --del tapegatewayd
fi
%endif

%if ! %compiling_client
%package -n castor-build-headers
Summary: Cern Advanced mass STORage
Group: Application/Castor
%description -n castor-build-headers
castor (Cern Advanced STORage system) - Header files required by the build system
%files -n castor-build-headers
%defattr(-,root,root)
%attr(0644,root,root) /usr/include/castor/castor/BaseAddress.hpp
%attr(0644,root,root) /usr/include/castor/castor/BaseCnvSvc.hpp
%attr(0644,root,root) /usr/include/castor/castor/BaseObject.hpp
%attr(0644,root,root) /usr/include/castor/castor/BaseSvc.hpp
%attr(0644,root,root) /usr/include/castor/castor/client/BaseClient.hpp
%attr(0644,root,root) /usr/include/castor/castor/client/IResponseHandler.hpp
%attr(0644,root,root) /usr/include/castor/castor/client/VectorResponseHandler.hpp
%attr(0644,root,root) /usr/include/castor/castor/CnvFactory.hpp
%attr(0644,root,root) /usr/include/castor/castor/Constants.hpp
%attr(0644,root,root) /usr/include/castor/castor/Converters.hpp
%attr(0644,root,root) /usr/include/castor/castor/db/cnv/DbBaseCnv.hpp
%attr(0644,root,root) /usr/include/castor/castor/db/DbBaseObj.hpp
%attr(0644,root,root) /usr/include/castor/castor/db/DbCnvSvc.hpp
%attr(0644,root,root) /usr/include/castor/castor/db/DbParamsSvc.hpp
%attr(0644,root,root) /usr/include/castor/castor/db/IDbResultSet.hpp
%attr(0644,root,root) /usr/include/castor/castor/db/IDbStatement.hpp
%attr(0644,root,root) /usr/include/castor/castor/db/ora/OraCnvSvc.hpp
%attr(0644,root,root) /usr/include/castor/castor/db/ora/OraCommonSvc.hpp
%attr(0644,root,root) /usr/include/castor/castor/dlf/Dlf.hpp
%attr(0644,root,root) /usr/include/castor/castor/dlf/IPAddress.hpp
%attr(0644,root,root) /usr/include/castor/castor/dlf/Message.hpp
%attr(0644,root,root) /usr/include/castor/castor/dlf/Param.hpp
%attr(0644,root,root) /usr/include/castor/castor/dlf/TimeStamp.hpp
%attr(0644,root,root) /usr/include/castor/castor/exception/Communication.hpp
%attr(0644,root,root) /usr/include/castor/castor/exception/Exception.hpp
%attr(0644,root,root) /usr/include/castor/castor/exception/Internal.hpp
%attr(0644,root,root) /usr/include/castor/castor/exception/InvalidArgument.hpp
%attr(0644,root,root) /usr/include/castor/castor/exception/NoEntry.hpp
%attr(0644,root,root) /usr/include/castor/castor/exception/OutOfMemory.hpp
%attr(0644,root,root) /usr/include/castor/castor/exception/SQLError.hpp
%attr(0644,root,root) /usr/include/castor/castor/Factories.hpp
%attr(0644,root,root) /usr/include/castor/castor/IAddress.hpp
%attr(0644,root,root) /usr/include/castor/castor/IClient.hpp
%attr(0644,root,root) /usr/include/castor/castor/ICnvFactory.hpp
%attr(0644,root,root) /usr/include/castor/castor/ICnvSvc.hpp
%attr(0644,root,root) /usr/include/castor/castor/IConverter.hpp
%attr(0644,root,root) /usr/include/castor/castor/IFactory.hpp
%attr(0644,root,root) /usr/include/castor/castor/io/AbstractSocket.hpp
%attr(0644,root,root) /usr/include/castor/castor/io/AbstractTCPSocket.hpp
%attr(0644,root,root) /usr/include/castor/castor/IObject.hpp
%attr(0644,root,root) /usr/include/castor/castor/io/ClientSocket.hpp
%attr(0644,root,root) /usr/include/castor/castor/io/ServerSocket.hpp
%attr(0644,root,root) /usr/include/castor/castor/IService.hpp
%attr(0644,root,root) /usr/include/castor/castor/ISvcFactory.hpp
%attr(0644,root,root) /usr/include/castor/castor/MessageAck.hpp
%attr(0644,root,root) /usr/include/castor/castor/metrics/Counter.hpp
%attr(0644,root,root) /usr/include/castor/castor/metrics/Histogram.hpp
%attr(0644,root,root) /usr/include/castor/castor/metrics/MetricsCollector.hpp
%attr(0644,root,root) /usr/include/castor/castor/ObjectSet.hpp
%attr(0644,root,root) /usr/include/castor/castor/query/DiskPoolQueryType.hpp
%attr(0644,root,root) /usr/include/castor/castor/rh/Client.hpp
%attr(0644,root,root) /usr/include/castor/castor/rh/FileQryResponse.hpp
%attr(0644,root,root) /usr/include/castor/castor/rh/FileResponse.hpp
%attr(0644,root,root) /usr/include/castor/castor/rh/IOResponse.hpp
%attr(0644,root,root) /usr/include/castor/castor/rh/Response.hpp
%attr(0644,root,root) /usr/include/castor/castor/server/BaseDaemon.hpp
%attr(0644,root,root) /usr/include/castor/castor/server/BaseServer.hpp
%attr(0644,root,root) /usr/include/castor/castor/server/BaseThreadPool.hpp
%attr(0644,root,root) /usr/include/castor/castor/server/DynamicThreadPool.hpp
%attr(0644,root,root) /usr/include/castor/castor/server/IThread.hpp
%attr(0644,root,root) /usr/include/castor/castor/server/ListenerThreadPool.hpp
%attr(0644,root,root) /usr/include/castor/castor/server/Mutex.hpp
%attr(0644,root,root) /usr/include/castor/castor/server/NotifierThread.hpp
%attr(0644,root,root) /usr/include/castor/castor/server/Queue.hpp
%attr(0644,root,root) /usr/include/castor/castor/server/SelectProcessThread.hpp
%attr(0644,root,root) /usr/include/castor/castor/server/SignalThreadPool.hpp
%attr(0644,root,root) /usr/include/castor/castor/Services.hpp
%attr(0644,root,root) /usr/include/castor/castor/stager/DiskCopyStatusCodes.hpp
%attr(0644,root,root) /usr/include/castor/castor/stager/FileRequest.hpp
%attr(0644,root,root) /usr/include/castor/castor/stager/ICommonSvc.hpp
%attr(0644,root,root) /usr/include/castor/castor/stager/IJobSvc.hpp
%attr(0644,root,root) /usr/include/castor/castor/stager/NsFileId.hpp
%attr(0644,root,root) /usr/include/castor/castor/stager/QryRequest.hpp
%attr(0644,root,root) /usr/include/castor/castor/stager/QueryParameter.hpp
%attr(0644,root,root) /usr/include/castor/castor/stager/Request.hpp
%attr(0644,root,root) /usr/include/castor/castor/stager/RequestQueryType.hpp
%attr(0644,root,root) /usr/include/castor/castor/stager/StageAbortRequest.hpp
%attr(0644,root,root) /usr/include/castor/castor/stager/StageFileQueryRequest.hpp
%attr(0644,root,root) /usr/include/castor/castor/stager/StageGetRequest.hpp
%attr(0644,root,root) /usr/include/castor/castor/stager/StagePrepareToGetRequest.hpp
%attr(0644,root,root) /usr/include/castor/castor/stager/StagePrepareToPutRequest.hpp
%attr(0644,root,root) /usr/include/castor/castor/stager/StagePrepareToUpdateRequest.hpp
%attr(0644,root,root) /usr/include/castor/castor/stager/StagePutRequest.hpp
%attr(0644,root,root) /usr/include/castor/castor/stager/StageRmRequest.hpp
%attr(0644,root,root) /usr/include/castor/castor/stager/StageUpdateRequest.hpp
%attr(0644,root,root) /usr/include/castor/castor/stager/SubRequestGetNextStatusCodes.hpp
%attr(0644,root,root) /usr/include/castor/castor/stager/SubRequest.hpp
%attr(0644,root,root) /usr/include/castor/castor/stager/SubRequestStatusCodes.hpp
%attr(0644,root,root) /usr/include/castor/castor/stager/SvcClass.hpp
%attr(0644,root,root) /usr/include/castor/castor/stager/TapeVid.hpp
%attr(0644,root,root) /usr/include/castor/castor/SvcFactory.hpp
%attr(0644,root,root) /usr/include/castor/castor/System.hpp
%attr(0644,root,root) /usr/include/castor/castor/VectorAddress.hpp
%attr(0644,root,root) /usr/include/castor/client/src/stager/stager_client_api_query.hpp
%attr(0644,root,root) /usr/include/castor/h/Castor_limits.h
%attr(0644,root,root) /usr/include/castor/h/Cgetopt.h
%attr(0644,root,root) /usr/include/castor/h/Cglobals.h
%attr(0644,root,root) /usr/include/castor/h/Cgrp.h
%attr(0644,root,root) /usr/include/castor/h/Cnetdb.h
%attr(0644,root,root) /usr/include/castor/h/Cns_api.h
%attr(0644,root,root) /usr/include/castor/h/Cns_constants.h
%attr(0644,root,root) /usr/include/castor/h/Cns_struct.h
%attr(0644,root,root) /usr/include/castor/h/common.h
%attr(0644,root,root) /usr/include/castor/h/Cpool_api.h
%attr(0644,root,root) /usr/include/castor/h/Cpwd.h
%attr(0644,root,root) /usr/include/castor/h/Ctape_api.h
%attr(0644,root,root) /usr/include/castor/h/Ctape_constants.h
%attr(0644,root,root) /usr/include/castor/h/Cthread_api.h
%attr(0644,root,root) /usr/include/castor/h/Cthread_flags.h
%attr(0644,root,root) /usr/include/castor/h/Cuuid.h
%attr(0644,root,root) /usr/include/castor/h/dlf_api.h
%attr(0644,root,root) /usr/include/castor/h/getacctent.h
%attr(0644,root,root) /usr/include/castor/h/getacct.h
%attr(0644,root,root) /usr/include/castor/h/getconfent.h
%attr(0644,root,root) /usr/include/castor/h/log.h
%attr(0644,root,root) /usr/include/castor/h/net.h
%attr(0644,root,root) /usr/include/castor/h/osdep.h
%attr(0644,root,root) /usr/include/castor/h/patchlevel.h
%attr(0644,root,root) /usr/include/castor/h/rfio_api.h
%attr(0644,root,root) /usr/include/castor/h/rfio_constants.h
%attr(0644,root,root) /usr/include/castor/h/rfio_errno.h
%attr(0644,root,root) /usr/include/castor/h/serrno.h
%attr(0644,root,root) /usr/include/castor/h/stager_api.h
%attr(0644,root,root) /usr/include/castor/h/stager_client_api_common.hpp
%attr(0644,root,root) /usr/include/castor/h/stager_client_api.h
%attr(0644,root,root) /usr/include/castor/h/stager_errmsg.h
%attr(0644,root,root) /usr/include/castor/h/stager_mapper.h
%attr(0644,root,root) /usr/include/castor/h/stager_uuid.h
%attr(0644,root,root) /usr/include/castor/h/trace.h
%attr(0644,root,root) /usr/include/castor/h/u64subr.h
%attr(0644,root,root) /usr/include/castor/h/vmgr_api.h
%attr(0644,root,root) /usr/include/castor/h/vmgr_constants.h
%attr(0644,root,root) /usr/include/castor/h/vmgr_struct.h
%attr(0644,root,root) /usr/include/castor/h/ypgetacctent.h
%endif

%if ! %compiling_client
%package -n castor-slp-plugin
Summary: Cern Advanced mass STORage
Group: Application/Castor
Requires: python, python-rpyc >= 3.1
%description -n castor-slp-plugin
castor (Cern Advanced STORage system) - CASTOR plugin for the simple log producer
%files -n castor-slp-plugin
%defattr(-,root,root)
%attr(-,root,bin) %dir /etc/simple-log-producer/plugins
%attr(0644,root,root) /etc/simple-log-producer/plugins/castor_base_file_parser.py*
%attr(0644,root,root) /etc/simple-log-producer/plugins/castor_rsyslogfile_header_parser.py*
%attr(0644,root,root) /etc/simple-log-producer/plugins/castor_rsyslogfile_body_parser.py*
%attr(0644,root,root) /etc/simple-log-producer/plugins/castor_rsyslogfile_oldheader_parser.py*
%endif

%if ! %compiling_client
%package -n castor-cockpit
Summary: Cern Advanced mass STORage
Group: Application/Castor
Requires: logrotate, python >= 2.6, python-rpyc >= 3.1, Django < 1.4, Django-south, mysql-server, MySQL-python, httpd, mod_wsgi, thrift
%description -n castor-cockpit
castor (Cern Advanced STORage system) - Castor monitoring Cockpit
%files -n castor-cockpit
%defattr(-,root,root)
%attr(-,root,bin) %dir /var/log/castor
%attr(0755,root,root) /var/www/castormon/*
%attr(0644,root,root) /etc/castor/cockpit-credentials.conf.example
%attr(0644,root,root) %config(noreplace) /etc/logrotate.d/castor-cockpit
%endif

%if ! %compiling_client
%package -n castor-mae
Summary: Cern Advanced mass STORage
Group: Application/Castor
Requires: python, python-rpyc >= 3.1, python-dirq, python-messaging, python-simplejson, hadoop-client
%description -n castor-mae
castor (Cern Advanced STORage system) - AI messaging consumer for the Metric Analysis Engine.
%files -n castor-mae
%defattr(-,root,root)
%attr(-,root,bin) %dir /var/log/castor
%attr(0755,root,root) /usr/bin/mae-consumer.py*
%attr(0755,root,root) /usr/lib/python*/site-packages/mae/*
%attr(0644,root,root) /etc/mae/mae.conf.example
%endif

%if ! %compiling_client
%package -n castor-hbase-consumer
Summary: Cern Advanced mass STORage
Group: Application/Castor
Requires: python, python-dirq, python-messaging, python-simplejson, happybase, thrift
%description -n castor-hbase-consumer
castor (Cern Advanced STORage system) - AI messaging consumer for HBase.
%files -n castor-hbase-consumer
%defattr(-,root,root)
%attr(-,root,bin) %dir /var/log/castor
%attr(0755,root,root) /usr/bin/hbase-consumer.py*
%attr(0755,root,root) /usr/lib/python*/site-packages/hbaseconsumerlib/*
%attr(0644,root,root) /etc/hbase-consumer/hbase-consumer.conf.example
%endif

%if ! %compiling_client
%package -n castor-lemon-sensor-py
Summary: Cern Advanced mass STORage
Group: Application/Castor
Requires: python, python-rpyc >= 3.1, lemon-sensor-pythonAPI
%description -n castor-lemon-sensor-py
castor (Cern Advanced STORage system) - Lemon sensor for the MAE - 
%files -n castor-lemon-sensor-py
%defattr(-,root,root)
%attr(0644,root,root) /usr/libexec/sensors/CastorMon.py*
%endif

%if ! %compiling_client
%package -n castor-traffic-shaper
Summary: Cern Advanced mass STORage
Group: Application/Castor
Requires: bash, initscripts, chkconfig, iproute, ethtool
%description -n castor-traffic-shaper
castor (Cern Advanced STORage system) - Traffic shaper for disk server's output, giving priority to tape servers
%files -n castor-traffic-shaper
%defattr(-,root,root)
%attr(0644,root,bin) %doc /usr/share/man/man8/castor-traffic-shaper.8castor.gz
%attr(0755,root,root) /etc/init.d/castor-traffic-shaper
%attr(0644,root,root) /etc/sysconfig/castor-traffic-shaper.example
%post -n castor-traffic-shaper
/sbin/chkconfig --add castor-traffic-shaper
/sbin/service castor-traffic-shaper start > /dev/null 2>&1 || :
%preun -n castor-traffic-shaper
if [ "$1" = 0 ]; then
    /sbin/service castor-traffic-shaper stop > /dev/null 2>&1 || :
    /sbin/chkconfig --del castor-traffic-shaper
fi
%endif

%if ! %compiling_client
%package -n castor-xrootd-plugin
Summary: Cern Advanced mass STORage
Group: Application/Castor
Requires: xrootd-server >= 3.3.2, xrootd-client >= 3.3.2, castor-lib = %{version}-%{release}
BuildRequires:  xrootd-server, xrootd-client, xrootd-libs-devel, xrootd-client-devel, xrootd-server-devel, xrootd-private-devel, xrootd-cl, xrootd-cl-devel
Obsoletes: xrootd-libtransfermanager,xrootd-xcastor2fs
%description -n castor-xrootd-plugin
castor (Cern Advanced STORage system) - Xrootd support of Castor - XBS-Obsoletes: xrootd-libtransfermanager, xrootd-xcastor2fs
%files -n castor-xrootd-plugin
%defattr(-,root,root)
%ifarch x86_64
%attr(0755,root,root) /usr/lib64/libXrdxCastor2ServerAcc.so*
%attr(0755,root,root) /usr/lib64/libXrdxCastor2Ofs.so*
%attr(0755,root,root) /usr/lib64/libXrdxCastor2Fs.so*
%attr(0755,root,root) /usr/bin/x2proc
%attr(0755,root,root) /usr/bin/x2cp
%attr(0755,root,root) /usr/bin/XrdTransfer
%attr(0644,root,root) /etc/sysconfig/xrootd.server.example
%attr(0644,root,root) /etc/sysconfig/xrootd.manager.example
%attr(0644,root,root) /etc/xrd.cf.server.example
%attr(0644,root,root) /etc/xrd.cf.manager.example
%attr(0755,root,root) /etc/cron.d/xrd-logs
%attr(0755,stage,st) /var/log/xrootd/manager
%attr(0755,stage,st) /var/log/xrootd/server
%attr(0755,stage,st) /var/log/xrootd/manager/proc
%attr(0755,stage,st) /var/log/xrootd/server/proc
%attr(0755,root,st) /var/spool/xrootd/core
%attr(0755,root,st) /var/spool/xrootd/admin
%attr(0755,root,st) /var/spool/xrootd/manager
%attr(0755,root,st) /var/spool/xrootd/server
%attr(0775,stage,st) /var/run/xrootd/



%else
%attr(0755,root,root) /usr/lib/libXrdxCastor2ServerAcc.so*
%attr(0755,root,root) /usr/lib/libXrdxCastor2Ofs.so*
%attr(0755,root,root) /usr/lib/libXrdxCastor2Fs.so*
%attr(0755,root,root) /usr/bin/x2proc
%attr(0755,root,root) /usr/bin/x2cp
%attr(0755,root,root) /usr/bin/XrdTransfer
%attr(0644,root,root) /etc/sysconfig/xrootd.server.example
%attr(0644,root,root) /etc/sysconfig/xrootd.manager.example
%attr(0644,root,root) /etc/xrd.cf.server.example
%attr(0644,root,root) /etc/xrd.cf.manager.example
%attr(0755,root,root) /etc/cron.d/xrd-logs
%attr(0755,stage,st) /var/log/xrootd/manager
%attr(0755,stage,st) /var/log/xrootd/server
%attr(0755,stage,st) /var/log/xrootd/manager/proc
%attr(0755,stage,st) /var/log/xrootd/server/proc
%attr(0755,root,st) /var/spool/xrootd/core
%attr(0755,root,st) /var/spool/xrootd/admin
%attr(0755,root,st) /var/spool/xrootd/manager
%attr(0755,root,st) /var/spool/xrootd/server
%attr(0775,stage,st) /var/run/xrootd/



%endif
%post -n castor-xrootd-plugin
/sbin/chkconfig --add xrootd
/sbin/chkconfig --level 435 xrootd on
/sbin/service xrootd condrestart > /dev/null 2>&1 
%endif

